<?php
class ErrorHandler
{
	var $errorstack = array();
	function handle_mail_error($errno, $errstr, $errfile, $errline)
	{
		if(strpos($errstr,"It is not safe to rely on the system's timezone settings."))
			return;
		$this->errorstack []= array('number' => $errno, 'description' => $errstr, 'file' => $errfile, 'line' => $errline);
	}
	function getErrorMessage()
	{
		$msg="";
		foreach($this->errorstack as $err)
		{
			if($msg)
				$msg.="\r\n";
			$msg.=$err['description'];
		}
		return $msg;
	}
}

function runner_post_request($url, $parameters, $headers = array(), $certPath = false )
{
	$data = array();
	foreach ($parameters as $key => $value)
    {
    	$key = (string)$key;
        if ( is_array($value) )
        {
            foreach ($value as $item)
            {
				$item = (string)$item;
                $data[] = rawurlencode($key) . '=' . rawurlencode($item);
            }
        }
        else
        {
        	$value = (string)$value;
            $data[] = rawurlencode($key) . '=' . rawurlencode($value);
        }
    }
    $body = implode('&', $data);

    $options = array(
        CURLOPT_URL => $url . '?' . $body,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_INFILESIZE => -1,
        CURLOPT_TIMEOUT => 60,
        CURLOPT_CUSTOMREQUEST => "POST",
        CURLOPT_POST => true,
		CURLOPT_POSTFIELDS => $body,
		CURLOPT_SSL_VERIFYHOST => false,
		CURLOPT_SSL_VERIFYPEER => false,
        CURLOPT_HEADER => 0,
    );

    if ( count($headers) )
    {
    	$dataHeaders = array();
		foreach ($headers as $key => $value)
	        $dataHeaders[] = $key . ': ' . $value;

    	$options[CURLOPT_HTTPHEADER] = $dataHeaders;
    }

    if ( $certPath )
    	$options[CURLOPT_CAINFO] = $certPath;

    $result = array();
    $result["error"] = false;
    $result["content"] = null;

	try
	{
	    if (!$curl = curl_init())
	        throw new Exception('Unable to initialize cURL');

	    if (!curl_setopt_array($curl, $options))
	        throw new Exception(curl_error($curl));

	    if (!$result["content"] = curl_exec($curl))
	        throw new Exception(curl_error($curl));

	   	curl_close($curl);
    }
    catch ( Exception $e )
    {
 	   	$result["error"] = "CURL error: " . $e->getMessage();
	}

	return $result;
}

/**
 * Returns array
 * "content" => response body
 * "error" => error message if any
 */
function runner_http_request( $url, $body = "", $method = "GET", $headers = array(), $certPath = false )
{

	$options = array(
        CURLOPT_URL => $url,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_INFILESIZE => -1,
        CURLOPT_TIMEOUT => 60,
        CURLOPT_CUSTOMREQUEST => $method,
		CURLOPT_SSL_VERIFYHOST => false,
		CURLOPT_SSL_VERIFYPEER => false,
        CURLOPT_HEADER => true,
	);

	if( $body != "" ) {
		$options[CURLOPT_POSTFIELDS] = $body;
	}
	if( $method === "POST" ) {
		$options[CURLOPT_POST] = true;
	} else if(  $method !== "GET" ) {
		$options[ CURLOPT_CUSTOMREQUEST ] = $method;
	}

    if ( count($headers) )
    {
    	$dataHeaders = array();
		foreach ($headers as $key => $value)
	        $dataHeaders[] = $key . ': ' . $value;

    	$options[ CURLOPT_HTTPHEADER ] = $dataHeaders;
    }

    if ( $certPath )
    	$options[CURLOPT_CAINFO] = $certPath;

    $result = array();
    $result["error"] = false;
    $result["content"] = null;

	try
	{
	    if (!$curl = curl_init())
	        throw new Exception('Unable to initialize cURL');

	    if (!curl_setopt_array($curl, $options))
	        throw new Exception(curl_error($curl));

		$response = curl_exec($curl);
		if(  $response === false ) {
			throw new Exception( curl_error($curl) );
		}

		$result["responseCode"] = curl_getinfo( $curl, CURLINFO_HTTP_CODE );
		$headerSize = curl_getinfo( $curl, CURLINFO_HEADER_SIZE );
		$result["content"] = substr( $response, $headerSize );

		//	prevent PHP from returning false
		if( !$result["content"] )
			$result["content"] = "";

		$result["header"] = substr( $response, 0, $headerSize );

	   	curl_close($curl);
    }
    catch ( Exception $e )
    {
 	   	$result["error"] = "CURL error: " . $e->getMessage();
	}

	return $result;
}



/**
	PHPRunner wrapper for mail() function.
	$params array Input paramaters.
	The following parameters are supported:
	'from' Sender email address. If none specified an email address from the wizard will be used.
	'to' Receiver email address.
	'body' Plain text message body.
	'htmlbody' Html message body (do not use 'body' parameter in this case).
	'charset' Html message charset. If none specified the default website charset will be used.

	Returns array with data:
	"mailed" - indicates wheter mail sent or not
	"errors" - array of errors
		Each error is an array with the following keys:
		"number" - error number
		"description" - error description
		"file" - name of the php file in which error happened
		"line" - line number on which error happened

 * @param Array params
 * @return Array
 * @intellisense
 */
function runner_mail( $params )
{
	if( !GetGlobalData("useBuiltInMailer", false) )
	{
		include_once(getabspath('libs/phpmailer/class.phpmailer.php'));
		include_once(getabspath('libs/phpmailer/class.smtp.php'));
		return runner_mail_smtp($params);
	}

	$from = isset($params['from']) ? $params['from'] : "";
	if( !$from )
		$from = GetGlobalData("strFromEmail", "");

	$to = isset($params['to']) ? $params['to'] : "";
	$body = isset($params['body']) ? $params['body'] : "";
	$cc = isset($params['cc']) ? $params['cc'] : "";
	$bcc = isset($params['bcc']) ? $params['bcc'] : "";
	$replyTo = isset($params['replyTo']) ? $params['replyTo'] : "";
	$priority = isset($params['priority']) ? $params['priority'] : "";

	$charset = "";
	$isHtml = false;
	if( !$body )
	{
		$body = isset($params['htmlbody']) ? $params['htmlbody'] : "";
		$charset = isset($params['charset']) ? $params['charset'] : "";
		if( !$charset )
			$charset = "utf-8";
		$isHtml = true;
	}
	$subject = $params['subject'];

	//
	$header = "";
	if( $isHtml )
	{
		$header .= "MIME-Version: 1.0\r\n";
		$header .= 'Content-Type: text/html;' . ( $charset ? ' charset=' . $charset . ';' : '' ) . "\r\n";
	}

	if( $from )
	{
		if( strpos($from, '<') !== false )
			$header .= 'From: ' . $from . "\r\n";
		else
			$header .= 'From: <' . $from . ">\r\n";

		@ini_set("sendmail_from", $from);
	}

	if($cc)
		$header .= 'Cc: ' . $cc . "\r\n";

	if($bcc)
		$header .= 'Bcc: ' . $bcc . "\r\n";

	if ($priority)
		$header .= 'X-Priority: '.$priority."\r\n";

	if($replyTo)
	{
		if( strpos($replyTo, '<') !== false )
			$header .= 'Reply-to: '.$replyTo."\r\n";
		else
			$header .= 'Reply-to: <'.$replyTo.">\r\n";
	}

	$eh = new ErrorHandler();
	set_error_handler(array($eh, "handle_mail_error"));

	$res = false;
	if( !$header )
	{
		$res = mail($to, $subject, $body);
	}
	else
	{
		$res = mail($to, $subject, $body, $header);
	}

	restore_error_handler();
	return array( "success" => $res, "mailed" => $res, "errors" => $eh->errorstack, "message"=> $eh->getErrorMessage() );
}

/**
 * Gets absolute path
 *
 * @param string $path
 * @return string
 * @intellisense
 */
function getabspath($path)
{
	// get path to the root
	$pathToRoot = substr(dirname(__FILE__),0,strlen(dirname(__FILE__))-strlen("/include"));
	// cheks if there already we have absolute path
	if ($pathToRoot=="" || strpos($path, $pathToRoot) !== false)
		return $path;

	// add \ or / if needed
	if (substr($path, 0, 1) != "/" && substr($path, 0, 1) != "\\")
		$pathToRoot .= "/";

	$realPath = $pathToRoot.$path;
	return $realPath;
}


function httpDateString( $value ) {
	return gmdate( "D, d M Y H:i:s", $value ) . " GMT";
}


/**
 * Check if the path is absolute or not basing on data
 * obtained from the current file directory's path
 * @param String path
 * @return Boolean
 */
function isAbsolutePath($path)
{
	if( runner_substr($path, 0, 2) == "\\\\"  )
		return true;

	$pathToRoot = dirname(__FILE__);

	if( runner_substr($path, 0, 1) == "\/" && runner_substr($pathToRoot, 0, 1) == "\/")
		return true;

	$windowsPatter = '/^[a-z]{1}:\\\/i';
	if( preg_match($windowsPatter, $pathToRoot) &&  preg_match($windowsPatter, $path))
		return true;

	return false;
}

/**
 * Gets absolute url
 *
 * @param string $uri
 * @return string
 * @intellisense
 */
function getabsurl($uri)
{
	$here = 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	$realUrl = preg_replace('~#.*$~s', '', $here);
	$realUrl = preg_replace('~\?.*$~s', '', $realUrl);
	$realUrl = preg_replace('~/[^/]*$~s', '/'.$uri, $realUrl);
	return $realUrl;
}

/**
 * @intellisense
 */
function myfile_exists($filename)
{
	$file = @fopen($filename,"rb");
	if($file)
	{
		fclose($file);
		return true;
	}
	else
		return false;
}

/**
 * @intellisense
 */
function try_create_new_file($filename)
{
	$file = @fopen($filename,"x");
	if($file)
	{
		fclose($file);
		return true;
	}
	else
		return false;
}

function append_to_file( $filename, $str )
{
	$h = @fopen( $filename, "a" );
	if( !$h )
		return;
	fputs( $h, $str );
	fclose( $h );
}

//	read the whole file and return contents
/**
 * @intellisense
 * @param String filename
 * @param String mode?
 * @param Int length? 	Up to length number of bytes read
 */
function myfile_get_contents( $filename, $mode = "rb", $length = 0 )
{
	if(!is_uploaded_file($filename) && !file_exists($filename))
		return false;
	$handle = fopen($filename, $mode);
	if(!$handle)
		return false;
	
	$fsize = $length;
	if( !$length ) {
		fseek($handle, 0 , SEEK_END);
		$fsize = ftell($handle);
		fseek($handle, 0 , SEEK_SET);
	}

	$contents = "";
	if( $fsize )
		$contents = fread( $handle, $fsize );

	fclose( $handle );
	return $contents;
}

function myfile_get_contents_binary( $filename )
{
	return myfile_get_contents($filename, "rb");
}

function myurl_get_contents_binary( $url )
{
	return myurl_get_contents( $url );
}

function base64_encode_binary( $data )
{
	return base64_encode( $data );
}

function base64_decode_binary( $data )
{
	return base64_decode( $data );
}

function base64_bin2str( $data )
{
	return base64_encode( $data );
}

function base64_str2bin( $str )
{
	return base64_decode( $str );
}

/**
 * @intellisense
 */
function myurl_get_contents( $url )
{
	$refferer = @$_SERVER["HTTP_REFERER"] != "" ? @$_SERVER["HTTP_REFERER"] : "localhost";
	$opts = array(
		'http'=> array(
			'header'=> "User-Agent: PHPRunner 10\r\n" .
						"Referer: ".$refferer."\r\n"
		)
	);

	$context = stream_context_create( $opts );
	return file_get_contents( $url, false, $context );
}

/**
 * @intellisense
 */
function printfile($filename)
{
	$file = fopen($filename, "rb");
	$bufsize = 8*1024;
	while(!feof($file))
		echo fread($file, $bufsize);
	fclose($file);
}

/**
 * @intellisense
 */
function printfileByRange($filename, $startPos, $endPos)
{
	$fileSize = filesize($filename);
	$length = $endPos - $startPos + 1;
	$file = fopen($filename, "rb");
	if(fseek($file, $startPos) == 0)
	{
		$bufsize = 8*1024;
		if($length < $bufsize)
			$bufsize = $length;
		$totalRead = 0;
		while(!feof($file) && $totalRead < $length)
		{
			//reset time limit for big files
        	set_time_limit(0);
			print(fread($file, $bufsize));
			flush();
			if(ob_get_level())
        		ob_flush();
			$totalRead += $bufsize;
			if($totalRead + $bufsize > $length)
				$bufsize = $length - $totalRead;
		}
	}
	fclose($file);
}

/**
 * @intellisense
 */
function CreateThumbnail($value, $size, $ext)
{
	if(!function_exists("imagecreatefromstring"))
		return $value;

	$error_handler=set_error_handler("empty_error_handler");
	$image = imagecreatefromstring($value);
	if($error_handler)
		set_error_handler($error_handler);

	if(!$image)
		return $value;

	$width_old = imagesx($image);
	$height_old = imagesy($image);

	if($width_old>$size || $height_old>$size){
		if($width_old>=$height_old)
		{
			$final_height=(integer)($height_old*$size/$width_old);
			$final_width=$size;
		}
		else
		{
			$final_width=(integer)($width_old*$size/$height_old);
			$final_height=$size;
		}


	    $image_resized = imagecreatetruecolor( $final_width, $final_height );

	    if ($ext==".GIF" || $ext=="GIF" || $ext==".PNG" || $ext=="PNG") {
	      $trnprt_indx = imagecolortransparent($image);

	      // If we have a specific transparent color
	      if ($trnprt_indx >= 0) {

	     	// when index more than imagecolorstotal may occurs problems with gif
		    $totalColors = imagecolorstotal($image);
		    if ($trnprt_indx>=$totalColors && $totalColors>0){
		    	$trnprt_indx = imagecolorstotal($image)-1;
		    }

	        // Get the original image's transparent color's RGB values
	        $trnprt_color    = imagecolorsforindex($image, $trnprt_indx);

	        // Allocate the same color in the new image resource
	        $trnprt_indx    = imagecolorallocatealpha($image_resized, $trnprt_color['red'], $trnprt_color['green'], $trnprt_color['blue'],127);
	        $trnprt_indx    = imagecolorallocate($image_resized, 255,255,255);
	        // Completely fill the background of the new image with allocated color.
	        imagefill($image_resized, 0, 0, $trnprt_indx);

	        // Set the background color for new image to transparent
	        imagecolortransparent($image_resized, $trnprt_indx);

	      }
	      // Always make a transparent background color for PNGs that don't have one allocated already
	      elseif ($ext==".PNG" || $ext=="PNG") {

	        // Turn off transparency blending (temporarily)
	        imagealphablending($image_resized, false);

	        // Create a new transparent color for image
	        $color = imagecolorallocatealpha($image_resized, 0, 0, 0, 127);

	        // Completely fill the background of the new image with allocated color.
	        imagefill($image_resized, 0, 0, $color);

	        // Restore transparency blending
	        imagesavealpha($image_resized, true);
	      }
	    }

	 	imagecopyresampled($image_resized, $image, 0, 0, 0, 0, $final_width, $final_height, $width_old, $height_old);

	    ob_start();
		if($ext==".JPG" || $ext=="JPEG")
			imagejpeg($image_resized);
		elseif($ext==".PNG")
			imagepng($image_resized);
		else
			imagegif($image_resized);
		$ret=ob_get_contents();
		ob_end_clean();
		imagedestroy($image);
		imagedestroy($image_resized);
		return $ret;
	}
	imagedestroy($image);
	return $value;

}
/**
 * @intellisense
 */
function mysprintf($format, $params)
{
	$params2 = $params;
	array_unshift($params2, $format);
	return call_user_func_array('sprintf', $params2);
}

/**
 * @intellisense
 */
function now()
{
	return strftime("%Y-%m-%d %H:%M:%S");
}

/**
 * refine value passed by POST or GET method
 * @intellisense
 */
function refine($str)
{
	return $str;
}

/**
 * suggest image type by extension
 * @intellisense
 */
function SupposeImageType($file)
{
	if(strlen($file)>1 && $file[0]=='B' && $file[1]=='M')
		return "image/bmp";
	if(strlen($file)>2 &&  $file[0]=='G' && $file[1]=='I' && $file[2]=='F')
		return "image/gif";
	if(strlen($file)>3 &&  ord($file[0])==0xff && ord($file[1])==0xd8 && ord($file[2])==0xff)
		return "image/jpeg";
	if(strlen($file)>8 &&  ord($file[0])==0x89 && ord($file[1])==0x50 && ord($file[2])==0x4e && ord($file[3])==0x47
					   &&  ord($file[4])==0x0d && ord($file[5])==0x0a && ord($file[6])==0x1a && ord($file[7])==0x0a)
		return "image/png";
}

/**
 * @intellisense
 */
function prepare_file($value,$field,$controltype,$postfilename, $id)
{
	$filename="";
	$file=&$_FILES["value_".GoodFieldName($field)."_".$id];
	if($file["error"] && $file["error"]!=4)
		return false;
	if(trim($postfilename))
		$filename=refine(trim($postfilename));
	else
		$filename=$file['name'];
	if(substr($controltype,4,1)=="1")
	{
		$filename="";
		return array("filename" => "", "value" => "");
	}
	if(substr($controltype,4,1)=="0")
		return false;
	$ret=myfile_get_contents($file['tmp_name']);
	if(!$ret)
		return false;
	return array("filename" => $filename, "value" => $ret);
}

/**
 * @intellisense
 */
function prepare_upload($field, $controltype, $postfilename, $value, $table, $id, &$pageObject)
{
	$abs = $pageObject->pSet->isAbsolute($field);
	$file=&$_FILES["value_".GoodFieldName($field)."_".$id];
	$sbstr1 = substr($controltype,6,1);
	if($file["error"] || $value == "")
	{
		if($file["error"] != 4  && $sbstr1 != "1")
		return false;
	}
	if($sbstr1 == "1")
	{
		if(strlen($postfilename))
		{
			$pageObject->filesToDelete[]=new DeleteFile($postfilename, $pageObject->pSet->getUploadFolder($field), $abs);
			if($pageObject->pSet->getCreateThumbnail($field,$table))
				$pageObject->filesToDelete[]=new DeleteFile($pageObject->pSet->getStrThumbnail($field).$postfilename, $pageObject->pSet->getUploadFolder($field), $abs);
		}
		return "";
	}
	if(substr($controltype,6,1)=="0")
		return false;
	if(strlen($file['tmp_name']))
	{
		if(!$pageObject->pSet->getResizeOnUpload($field))
		{
			$pageObject->filesToMove[] = new MoveFile($file['tmp_name'],$value, $pageObject->pSet->getUploadFolder($field),$abs);
		}
		else
		{
			$contents = myfile_get_contents($file['tmp_name']);
			$ext = CheckImageExtension($file["name"]);
			$thumb = CreateThumbnail($contents, $pageObject->pSet->getNewImageSize($field), $ext);
			$pageObject->filesToSave[] = new SaveFile($thumb,$value, $pageObject->pSet->getUploadFolder($field),$abs);
		}
	}
	return $value;
}

/**
 * @intellisense
 */
function FieldSubmitted($field)
{
	return in_assoc_array("type_".GoodFieldName($field),$_POST) || in_assoc_array("value_".GoodFieldName($field),$_POST)
		|| in_assoc_array("value_".GoodFieldName($field),$_FILES);
}

/**
 * @intellisense
 */
function GetUploadedFileContents($name)
{
	return myfile_get_contents($_FILES[$name]['tmp_name']);
}

/**
 * @intellisense
 */
function GetUploadedFileName($name)
{
	return $_FILES[$name]["name"];
}

/**
 * @param &Array values
 * @param &Array blobfields
 * @param RunnerPage pageobject
 * @return Array
 * @intellisense
 */
function PrepareBlobs(&$values, &$blobfields, $pageObject)
{
	$blobs = array();

	if( $pageObject->connection->dbType == nDATABASE_Oracle || $pageObject->connection->dbType == nDATABASE_DB2 || $pageObject->connection->dbType == nDATABASE_Informix )
	{
		//	replace blobs with EMPTY_BLOB()
		foreach($blobfields as $bfield)
		{
			$blobs[ $pageObject->getTableField( $bfield ) ] = $values[ $bfield ];

			if( $pageObject->connection->dbType == nDATABASE_Oracle )
				$values[ $bfield ] = "EMPTY_BLOB()";
			else
				$values[ $bfield ] = "?";
		}
	}
	else
	{
		//	no special processing required
		$blobfields = array();
	}

	return $blobs;
}

/**
 * @intellisense
 * @param RunnerPage pageObj
 * @param String strSQL
 * @param &Array blobs
 */
function ExecuteUpdate( &$pageObj, $strSQL, &$blobs )
{
	$blobTypes = array();
	if( $pageObj->connection->dbType == nDATABASE_Informix )
	{
		foreach($blobs as $fieldname => $fieldvalue)
		{
			$blobTypes[ $fieldname ] = $pageObj->pSet->getFieldType( $fieldname );
		}
	}
	LogInfo($strSQL);
	if( !$pageObj->connection->execWithBlobProcessing( $strSQL, $blobs, $blobTypes ) )
	{
		$pageObj->setDatabaseError( $pageObj->connection->lastError() );
		return false;
	}
	return true;
}

/**
 * @intellisense
 */
function runner_move_uploaded_file($source, $dest)
{
	move_uploaded_file($source, $dest);
}

/**
 * @intellisense
 */
function runner_save_file($filename, $contents)
{
	if(file_exists($filename))
		@unlink($filename);
	$th = fopen($filename, "w");
	fwrite($th, $contents);
	fclose($th);
}

/**
 * @intellisense
 */
function runner_delete_file($file)
{
	if(myfile_exists($file))
		@unlink($file);
}

/**
 * @intellisense
 */
function runner_copy_file($source, $dest)
{
	copy($source, $dest);
}

/**
 * @intellisense
 */
function GetCurrentYear()
{
	$tm=localtime(time(),true);
	return $tm["tm_year"]+1900;
}

/**
 * @intellisense
 */
function sortMembers(&$arr)
{
	usort($arr, "sortfunc_members");
}

/**
 * @intellisense
 */
function sortfunc_members(&$a,&$b)
{
	global $sortgroup,$sortorder;
	$gcount=count($a["usergroup_boxes"]["data"]);
	for($i=0;$i<$gcount;$i++)
		if($a["usergroup_boxes"]["data"][$i]["usergroup_box"]["data"][0]["group"]==$sortgroup)
			break;
	if($i==$gcount || $a["usergroup_boxes"]["data"][$i]["usergroup_box"]["data"][0]["checked"]==$b["usergroup_boxes"]["data"][$i]["usergroup_box"]["data"][0]["checked"])
	{
//	compare by username
		if($a["user"]==$b["user"])
			return 0;
		if($a["user"]>$b["user"])
			return 1;
		return -1;
	}
	if($sortorder=="a" && $a["usergroup_boxes"]["data"][$i]["usergroup_box"]["data"][0]["checked"]=="")
		return 1;
	if($sortorder=="d" && $b["usergroup_boxes"]["data"][$i]["usergroup_box"]["data"][0]["checked"]=="")
		return 1;
	return -1;
}

/**
 * return refined POST or GET value - single value or array
 * @intellisense
 */
function postvalue($name)
{
	if(isset($_POST[$name]))
		$value=$_POST[$name];
	else if(isset($_GET[$name]))
		$value=$_GET[$name];
	else
		return "";
	if(!is_array($value))
		return refine($value);
	$ret=array();
	foreach($value as $key=>$val)
		$ret[$key]=refine($val);
	return $ret;
}

function getCustomMapIcon($field, $table, $data)
{
	global $strTableName;
	$icon = "";
	if(!$table)
		$table = $strTableName;


	return $icon;
}

function getDashMapCustomIcon( $dashName, $dashElementName, $data )
{
	$icon = "";
}

/**
 * return custom expression
 * @intellisense
 */
function CustomExpression($value, $data, $field, $ptype, $table="")
{
	global $strTableName;
	if(!$table)
		$table = $strTableName;
				if($table=="item" && $field=="id")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["itemform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="cash_receipt" && $field=="Print")
	{
		/*
//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["cash_receipt"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}
*/

if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=?_emo.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>EMO</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="cash_receipt" && $field=="Print1")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["creceiptform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
};
		return $value;
	}
				if($table=="cash_receipt" && $field=="Print2")
	{
		
//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["cash_receipt2"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>AR</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="purchase" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["purchaseform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="purchase" && $field=="Print1")
	{
		//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["purchaseform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";


//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["salesform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=2307p_FBC.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="cash_disbursment" && $field=="Print")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report="."CheckVoucher_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="cash_disbursment" && $field=="Print1")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=check1.rptdesign". $_SESSION["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
};
		return $value;
	}
				if($table=="cash_disbursment" && $field=="check_print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION['check_print'] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="cash_disbursment" && $field=="2307")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["salesform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=2307_FBC.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}

;
		return $value;
	}
				if($table=="cash_disbursment" && $field=="Print3")
	{
		



if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Cash_Disbursement_ERP_v22.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="cash_disbursment" && $field=="Print4")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Check2.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="cash_disbursment" && $field=="Print5")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=check2toast.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="general_journal" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["gjournalform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}

;
		return $value;
	}
				if($table=="report_center" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Sales Report" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Disbursement Reports" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Financial Reports" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchase Reports" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Receivable Reports" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Taxation Reports" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="beg_bal" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="General Journal Reports" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Inventory Reports" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="bank_recon" && $field=="Print")
	{
		

$value = "<a target='_blank' href='" . "reconcile/reconcile.php?bankid=".$data['id']. "'>Start</a>";;
		return $value;
	}
				if($table=="deposit" && $field=="Print")
	{
		if($data['status'] =="Approved"){	
	
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "DepositForm_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
	
}	
	
else	
{	
$value ="";	
}	











;
		return $value;
	}
				if($table=="recon_CR" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Cash_Receipt_8boox.rptdesign&txnid=".$data['id']."&ea=".$data['company']."'>Print</a>";;
		return $value;
	}
				if($table=="Recon_CV" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Cash_Disbursement_8boox.rptdesign=".$data['id']."&ea=".$data['company']."'>Print</a>";;
		return $value;
	}
				if($table=="dr" && $field=="wo_price")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["wopform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="dr" && $field=="w_price")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["wpform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="dr" && $field=="receipt")
	{
		if($data['status'] == "Approved"){
	$value = "<a href='".$_SESSION["path"]."frameset?__report=". 
	"DeliveryReceipt_foodbasket".".rptdesign"."&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}else{ $value = ""; };
		return $value;
	}
				if($table=="dr" && $field=="Print1")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["drpform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}



;
		return $value;
	}
				if($table=="purchase_order" && $field=="Print")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["poform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="purchase_order_receiving" && $field=="Print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["poreceivingform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="ppe_list" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="ppe_list" && $field=="batch_sticker")
	{
		$value = "<a href='".$_SESSION["path"]."frameset?__report=". 
	"BatchSticker_foodbasket".".rptdesign"."&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";;
		return $value;
	}
				if($table=="reimbursement" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "ReimbursementForm_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="quotation" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["quoform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
};
		return $value;
	}
				if($table=="case" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="production" && $field=="Print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["productionform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="issue" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["issueform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="disposed" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Disposal_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="backload" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["backloadform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}



;
		return $value;
	}
				if($table=="backload_detail" && $field=="ref_id")
	{
		$value="";;
		return $value;
	}
				if($table=="trip_ticket" && $field=="print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["tticketform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";;
		return $value;
	}
				if($table=="position" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="service_center" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="fixed_assets_return" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["fixedassetsreturnform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="Prospect_customers" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="petty_cash" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PettyCashForm_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}

;
		return $value;
	}
				if($table=="petty_cash" && $field=="Summary")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Petty_Cash_Summary_ERP_Hovid.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&NewParameter=".date('Y-m-d', strtotime($data['Transadate'] . '-1 week'))."&NewParameter1=" . date('Y-m-d', strtotime($data['Transadate'] . '+1 day'))   ."&NewParameter2=".$data['Account No']."&NewParameter3=".$data['Account No']."'>Print</a>";

;
		return $value;
	}
				if($table=="center_replenishment" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["centerrepleform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="credit_memo" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["creditmemoform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="debit_memo" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["debitmemoform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="debit_memo_detail" && $field=="ref_id")
	{
		$value = "";;
		return $value;
	}
				if($table=="project_replenishment" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["pjrepform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="sales" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "SalesInvoice_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

//salesform

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="Sales_Order_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Sales_Order_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Sales_Order_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Sales_Order_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Quotation_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Qoutation_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Quotation_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Qoutation_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Reimbursement_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Reimbursement_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Reimbursement_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Reimbursement_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Project_Replenishment_for_checking" && $field=="Print")
	{
		
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Project_Replenishment_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Project_Replenishment_for_approval" && $field=="Print")
	{
		
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Project_Replenishment_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchases_Order_for_checking2" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Purchase_Order_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchases_Order_for_approval2" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Purchase_Order_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Receiving_for_checking2" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PO_Receiving_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Receiving_for_approval2" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PO_Receiving_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Delivery_Receipt_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Delivery_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Delivery_Receipt_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Delivery_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Production_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Production_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Production_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Production_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Issue_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Supply_Issue_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Issue_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Supply_Issue_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Return_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Return_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Disposal_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Supply_Dispose_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Fixed_Asset_Issue_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Fixed_Asset_Issue_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Fixed_Asset_Issue_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Fixed_Asset_Issue_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Fixed_Asset_Return_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Fixed_Asset_Return_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Fixed_Asset_Return_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Fixed_Asset_Return_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Petty_Cash_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Petty_Cash_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Petty_Cash_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Petty_Cash_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Deposit_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Deposit_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Deposit_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Deposit_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Credit_Memo_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Credit_Memo_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Credit_Memo_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Credit_Memo_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Debit_Memo_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Debit_Memo_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="debit_memo_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Debit_Memo_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchases_for_checking" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["apv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchases_for_checking" && $field=="Print1")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Credit_Purchase_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchases_for_approval" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["apv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchases_for_approval" && $field=="Print1")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Credit_Purchase_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Sales_for_checking" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Credit_Sale_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Sales_for_approval" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Credit_Sale_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["cv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="Print1")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["cv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="check_print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $value['check_print'] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["cv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="Print1")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["cv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="check_print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $value['check_print'] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="document" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["gv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="General_Journal_for_checking" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["gv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="General_Journal_for_approval" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["gv"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="estimate" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["estimateform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="purchase_request" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PurchaseRequest_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}






;
		return $value;
	}
				if($table=="inventory_adj" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["inventoryadjustment"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="inventory_tranfer" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["inventorytransform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="inventory_tranfer" && $field=="signature")
	{
		$value = "<image src='../signaturepic/"  . $data["signature"] . "' width='200' height ='100' />";
		return $value;
	}
				if($table=="Customers" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Suppliers" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Statement_of_Account" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["soaccountform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Inventory_Adjustment_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Fixed_Asset_Return_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Inventory_Adjustment_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Fixed_Asset_Return_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="for_checking" && $field=="View")
	{
		$value = "<a href='" . str_replace(" ","_",$data["Transaction"]) . "_for_checking_list.php'>View</a>";;
		return $value;
	}
				if($table=="for_approval" && $field=="View")
	{
		$value = "<a href='" .  str_replace(" ","_",$data["Transaction"]) . "_for_approval_list.php'>View</a>";;
		return $value;
	}
				if($table=="Estimate_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Qoutation_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Estimate_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Qoutation_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Prospect_customers_to_Customer" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="production_request" && $field=="Print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["prorequestform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="Purchase_Request_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PO_Receiving_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Production_Request_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Production_Request_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Inventory_Transfer_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Transfer_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Inventory_Transfer_for_approval" && $field=="signature")
	{
		$value = "<image src='../signaturepic/"  . $data["signature"] . "' width='200' height ='100' />";
		return $value;
	}
				if($table=="Purchase_Request_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PO_Receiving_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Production_Request_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Production_Request_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Inventory_Transfer_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Transfer_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Inventory_Transfer_for_checking" && $field=="signature")
	{
		$value = "<image src='../signaturepic/"  . $data["signature"] . "' width='200' height ='100' />";
		return $value;
	}
				if($table=="Backload_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["backloadform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="backload_detail_for_approval" && $field=="ref_id")
	{
		$value="";;
		return $value;
	}
				if($table=="Backload_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["backloadform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="backload_detail_for_checking" && $field=="ref_id")
	{
		$value="";;
		return $value;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["ar"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="Print1")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["creceiptform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["ar"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="Print1")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["creceiptform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Service_Report_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["sreportform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Service_Report_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["sreportform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="return" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "ReturnSlip_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="fixed_asset_issue" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Fixed_Asset_Issue_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="trip_ticket_for_approval" && $field=="print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["tticketform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="trip_ticket_for_checking" && $field=="print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["tticketform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="quality_control" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["qcontrol"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}



;
		return $value;
	}
				if($table=="budget" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["budgetform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="repairs_and_maintenance" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["rmaintenanceform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="sales_order" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["sorderform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="vat_relief_importation" && $field=="Reconciliation")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=list_of_importation.rptdesign&txnid=".$data['Vat_period']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
;
		return $value;
	}
				if($table=="vat_relief_purchases" && $field=="Reconciliation")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=list_of_purchases.rptdesign&txnid=".$data['Vat_period']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
;
		return $value;
	}
				if($table=="vat_relief_sales" && $field=="Reconciliation")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=list_of_sales.rptdesign&txnid=".$data['Vat_period']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
;
		return $value;
	}
				if($table=="marketing_request_form" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["mrform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";
}

else
{
$value ="";
}



;
		return $value;
	}
				if($table=="Disposal_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Supply_Dispose_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Open_Trip_Ticket_Report" && $field=="print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["tticketform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="request_for_payment" && $field=="id")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["rfpaymentform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="request_for_payment" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "RequestForPayment_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
};
		return $value;
	}
				if($table=="pending_items_reminders" && $field=="view")
	{
		//$value = "<a href='" . $data["View"] . "'>View</a>";


$value = $data["View"] ;;
		return $value;
	}
				if($table=="pending_items_reminders" && $field=="Create")
	{
		$value = "<a href='" . $data["view"] . "'>View</a>";;
		return $value;
	}
				if($table=="issue_components" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["issuecom"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="disposed_inv" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["disinvform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}

;
		return $value;
	}
				if($table=="For_Approval_Dashboard" && $field=="View")
	{
		$value = "<a href='" .  str_replace(" ","_",$data["Transaction"]) . "_for_approval_list.php'>View</a>";;
		return $value;
	}
				if($table=="For_Checking_Dashboard" && $field=="View")
	{
		$value = "<a href='" . str_replace(" ","_",$data["Transaction"]) . "_for_checking_list.php'>View</a>";;
		return $value;
	}
				if($table=="packing_list" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["plist"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
};
		return $value;
	}
				if($table=="Purchases_Order_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Purchase_Order_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Purchases_Order_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Purchase_Order_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Receiving_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PO_Receiving_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Receiving_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "PO_Receiving_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Center_Replenishment_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Center_Replenishment_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Center_Replenishment_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Center_Replenishment_ERP.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="quality_control_for_approval" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["qcform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="quality_control_for_checking" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["qcform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="Current_Accounts" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="marketing_request_form_for_checking" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["mrform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";
}

else
{
$value ="";
}



;
		return $value;
	}
				if($table=="marketing_request_form_for_approval" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["mrform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";
}

else
{
$value ="";
}



;
		return $value;
	}
				if($table=="logistic_open_inventory_tranfer" && $field=="signature")
	{
		$value = "<image src='../signaturepic/"  . $data["signature"] . "' width='200' height ='100' />";
		return $value;
	}
				if($table=="request_for_quote" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["rfqform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
};
		return $value;
	}
				if($table=="project_progress_billing" && $field=="Print")
	{
		
$value = "<a href='" . $_SESSION["path"] . "frameset?__report=progressbilling.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["Print"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

;
		return $value;
	}
				if($table=="checklist" && $field=="description")
	{
		$value = "<a href='" . $data['url']."'>".$data['description']."</a>";
;
		return $value;
	}
				if($table=="Check_Release" && $field=="Print")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["cashdisform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="Check_Release" && $field=="Print1")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="Check_Release" && $field=="check_print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $value['check_print'] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="Check_Release" && $field=="2307")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["salesform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=2307.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";
}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="Check_Release" && $field=="Print3")
	{
		



if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Cash_Disbursement_ERP_v22.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="Check_Release" && $field=="Print4")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Check2.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="Check_Release" && $field=="Print5")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=check2toast.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="canvas" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["canvasform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}






;
		return $value;
	}
				if($table=="inventory_tranfer_request" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["inventorytransrequestform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="branch_sales" && $field=="Print")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["branchsalesform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
};
		return $value;
	}
				if($table=="inventory_tranfer_view" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["inventorytransform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="inventory_tranfer_view" && $field=="signature")
	{
		$value = "<image src='../signaturepic/"  . $data["signature"] . "' width='200' height ='100' />";
		return $value;
	}
				if($table=="expense" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["expenseform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
;
		return $value;
	}
				if($table=="report_center_fs" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_fs" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_books" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_books" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_sales" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_sales" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_tax" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_tax" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_ap" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_ap" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_ar" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_ar" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_purchases" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_purchases" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_inventory" && $field=="Print")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="report_center_inventory" && $field=="file")
	{
		$value = "<a target='_blank' href='" . $_SESSION["path"] . "frameset?__report=".$data['file']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="picklist" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["picklist"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
};
		return $value;
	}
				if($table=="projects" && $field=="BOM")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=project_bom.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
;
		return $value;
	}
				if($table=="projects" && $field=="SOA")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=project_soa.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
;
		return $value;
	}
				if($table=="projects" && $field=="Gantt")
	{
		$value = "<a href='gantt/index.php?projectid=".$data['id']."'>Gantt</a>";
;
		return $value;
	}
				if($table=="return_components" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["returncompform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_production" && $field=="Print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["productionform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_cases" && $field=="Print")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". "Medtek_salesInvoice.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="inventory_tranfer_mobile" && $field=="Print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["inventorytransform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="inventory_tranfer_mobile" && $field=="signature")
	{
		$value = "<image src='../signaturepic/"  . $data["signature"] . "' width='200' height ='100' />";
		return $value;
	}
				if($table=="item_with_balances" && $field=="id")
	{
		$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["itemform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";;
		return $value;
	}
				if($table=="asset_accountability" && $field=="print")
	{
		if($data['status'] == "Approved"){
	$value = "<a href='".$_SESSION["path"]."frameset?__report=". 
	"AssetAccountabilityForm_foodbasket".".rptdesign"."&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}else{ $value = ""; };
		return $value;
	}
				if($table=="cash_pullout" && $field=="print")
	{
		if($data['status'] == "Approved"){
	$value = "<a href='".$_SESSION["path"]."frameset?__report=CashPullOutForm_foodbasket.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}else{ $value = ""; };
		return $value;
	}
				if($table=="liquidation" && $field=="print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["liq"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="loan" && $field=="print")
	{
		if($data['status'] == "Approved"){
	$value = "<a href='".$_SESSION["path"]."frameset?__report=ValeSheet_foodbasket.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}else{ $value = ""; };
		return $value;
	}
				if($table=="marketing_job_order" && $field=="print")
	{
		if($data['status'] == "Approved"){
	$value = "<a href='".$_SESSION["path"]."frameset?__report=". 
	"MarketingJobOrderForm_foodbasket".".rptdesign"."&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}else{ $value = ""; };
		return $value;
	}
				if($table=="spoilage" && $field=="print")
	{
		if($data['status'] == "Approved"){
	$value = "<a href='".$_SESSION["path"]."frameset?__report=". 
	"SpoilageReport_foodbasket".".rptdesign"."&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}else{ $value = ""; };
		return $value;
	}
				if($table=="tara_sheet" && $field=="print")
	{
		if($data['status'] == "Approved"){
	$value = "<a href='".$_SESSION["path"]."frameset?__report=TaraSheet_foodbasket.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}else{ $value = ""; };
		return $value;
	}
				if($table=="transmittal_slip" && $field=="print")
	{
		$value = "<a href='".$_SESSION["path"]."frameset?__report=TransmittalSlip_foodbasket.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"].
	"&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
;
		return $value;
	}
				if($table=="canvass" && $field=="print")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["canvasform"] ."&txnid=".$data['iD']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}






;
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="Print")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report="."CheckVoucher_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="Print1")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=check1.rptdesign". $_SESSION["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
};
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="check_print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION['check_print'] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="2307")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["salesform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=2307_Hovid.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}

;
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="Print3")
	{
		



if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Cash_Disbursement_ERP_v22.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="Print4")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Check2.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="Print5")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=check2toast.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="Print")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report="."CheckVoucher_foodbasket.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="Print1")
	{
		if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=check1.rptdesign". $_SESSION["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
};
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="check_print")
	{
		if($data['status'] ="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION['check_print'] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="2307")
	{
		//$value ="<a href='cash_sales_Print_print.php?txnid=".$data['id']."'>Print</a>";
if($data['status'] =="Approved"){

//$value = "<a href='" . $_SESSION["path"] . "frameset?__report=". $_SESSION["salesform"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=2307_Hovid.rptdesign&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";
}

else
{
$value ="";
}

;
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="Print3")
	{
		



if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Cash_Disbursement_ERP_v22.rptdesign" ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."&&__dpi=96&__format=pdf&__pageoverflow=2&__overwrite=false'>Print</a>";



}

else
{
$value ="";
}
;
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="Print4")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=Check2.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="Print5")
	{
		
if($data['status'] =="Approved"){

$value = "<a href='" . $_SESSION["path"] . "frameset?__report=check2toast.rptdesign". $data["check_print"] ."&txnid=".$data['id']."&ea=".$_SESSION["ea"]."'>Print</a>";

}

else
{
$value ="";
}


;
		return $value;
	}
	return $value;
}


/**
 * return custom expression for file
 * @intellisense
 */
function fileCustomExpression($file, $data, $field, $ptype, $table )
{
	$value = "";
				if($table=="cash_receipt" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="cash_receipt" && $field=="ewt_certificate")
	{
		;
		return $value;
	}
				if($table=="cash_receipt" && $field=="ewt_certficate")
	{
		;
		return $value;
	}
				if($table=="purchase" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="cash_disbursment" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="general_journal" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="deposit" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="dr" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="dr" && $field=="signature")
	{
		;
		return $value;
	}
				if($table=="purchase_order" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="purchase_order_receiving" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="item_group" && $field=="picture")
	{
		;
		return $value;
	}
				if($table=="reimbursement" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="quotation" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="issue" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="backload" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="fixed_assets_return" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="petty_cash" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="center_replenishment" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="credit_memo" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="debit_memo" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="project_replenishment" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Sales_Representatives" && $field=="files")
	{
		;
		return $value;
	}
				if($table=="sales" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Sales_Order_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Sales_Order_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Quotation_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Quotation_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Reimbursement_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Reimbursement_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Project_Replenishment_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Project_Replenishment_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchases_Order_for_checking2" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchases_Order_for_approval2" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Receiving_for_checking2" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Receiving_for_approval2" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Delivery_Receipt_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Delivery_Receipt_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Production_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Production_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Issue_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Issue_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Return_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Return_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Fixed_Asset_Issue_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Fixed_Asset_Issue_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Fixed_Asset_Return_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Fixed_Asset_Return_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Petty_Cash_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Petty_Cash_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Deposit_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Deposit_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Credit_Memo_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Credit_Memo_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Debit_Memo_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="debit_memo_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchases_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchases_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Sales_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Sales_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="General_Journal_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="General_Journal_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="submission_details" && $field=="File")
	{
		;
		return $value;
	}
				if($table=="estimate" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="purchase_request" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Customers" && $field=="files")
	{
		;
		return $value;
	}
				if($table=="Suppliers" && $field=="files")
	{
		;
		return $value;
	}
				if($table=="Estimate_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Estimate_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="production_request" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Credit_Card_monitoring" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Request_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Production_Request_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Inventory_Transfer_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Request_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Production_Request_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Inventory_Transfer_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Backload_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Backload_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Service_Report_for_approval" && $field=="picture")
	{
		;
		return $value;
	}
				if($table=="Service_Report_for_checking" && $field=="picture")
	{
		;
		return $value;
	}
				if($table=="return" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="fixed_asset_issue" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Available_Vehicles" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="marketing_colateral" && $field=="company")
	{
		;
		return $value;
	}
				if($table=="sales_order" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Quotation_Dashboard_Customer" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Delivery_Receipt_Dashboard_Customer" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Delivery_Receipt_Dashboard_Customer" && $field=="signature")
	{
		;
		return $value;
	}
				if($table=="Sales_Dashboard_Customer" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Backload_Dashboard_Customer" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Request_Dashboard_Supplier" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Order_Dashboard_Supplier" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Debit_Memo_Dashboard_Supplier" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Request_Dashboard_Item" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Order_Dashboard_Item" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Item" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="request_for_payment_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="request_for_payment_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Deposit_Report" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Deposit_in_transit_Report" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Outstanding_Checks_Report" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="sales_per_sales_rep_Report" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Quotation_Dashboard" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Sales_Order_Dashboard" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Reimbursement_Dashboard" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="request_for_payment" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="issue_components" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="disposed_inv_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="production_request_report" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="approved_sales_order" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="purchase_order_for_receiving" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="issue_components_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="issue_components_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchases_Order_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Purchases_Order_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Receiving_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Receiving_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="cash_sales_Report" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="cash_sales_Report" && $field=="ewt_certificate")
	{
		;
		return $value;
	}
				if($table=="Center_Replenishment_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Center_Replenishment_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="quality_control_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="quality_control_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="DR_per_Item" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="DR_per_Item" && $field=="signature")
	{
		;
		return $value;
	}
				if($table=="Logistic_Available_Vehicles" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="request_for_quote" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="request_for_quote_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="Check_Release" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="canvas" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="branch_sales" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="picklist" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="picklist_for_approval" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="picklist_for_checking" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="return_components" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="fixed_asset_time_usage" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="project_name" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="new_ticket" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="new_ticket" && $field=="file01")
	{
		;
		return $value;
	}
				if($table=="liquidation" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="open_cv_for_por" && $field=="file")
	{
		;
		return $value;
	}
				if($table=="open_cv_for_liq" && $field=="file")
	{
		;
		return $value;
	}
	return $value;
}


/**
 * return Lookup Wizard Where expression
 * @intellisense
 */
function GetLWWhere($field, $ptype, $table = "")
{
	global $strTableName;
	if(!$table)
		$table = $strTableName;
		if($table=="item" && $field=="Vat Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="item" && $field=="purchase_vat_type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="cash_receipt" && $field=="bank")
	{
		$strWhere = " type = 'Receipt' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="cash_receipt" && $field=="ref_no")
	{
		$strWhere = "Status = 'Approved'";
		return $strWhere;
	}
		if($table=="cash_receipt" && $field=="checked_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="cash_receipt" && $field=="approved_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="purchase" && $field=="approved_by")
	{
		$strWhere = "transaction = 2 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase" && $field=="checked_by")
	{
		$strWhere = "transaction = 2 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="cash_disbursment" && $field=="bank")
	{
		$strWhere = " type = 'Disbursement' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="cash_disbursment" && $field=="checked_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="cash_disbursment" && $field=="approved_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="cash_disbursment" && $field=="default_vat_type")
	{
		$strWhere = " purchase_only =1 ";
		return $strWhere;
	}
		if($table=="general_journal" && $field=="approved_by")
	{
		$strWhere = "transaction = 4 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="general_journal" && $field=="checked_by")
	{
		$strWhere = "transaction = 4 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="bank_recon" && $field=="default_chart_of_account")
	{
		$strWhere = " `Cash Account` = 1 ";
		return $strWhere;
	}
		if($table=="deposit" && $field=="checked_by")
	{
		$strWhere = "transaction = 31 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="deposit" && $field=="approved_by")
	{
		$strWhere = "transaction = 31 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="recon_CR" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Customer' ";
		return $strWhere;
	}
		if($table=="Recon_CV" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' ";
		return $strWhere;
	}
		if($table=="dr" && $field=="checked_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="dr" && $field=="approved_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase_order" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="purchase_order" && $field=="approved_by")
	{
		$strWhere = "transaction = 11 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase_order" && $field=="checked_by")
	{
		$strWhere = "transaction = 11 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="purchase_order_receiving" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="purchase_order_receiving" && $field=="approved_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase_order_receiving" && $field=="checked_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="System_preference" && $field=="default_receipt_bank")
	{
		$strWhere = " type = 'Receipt' or type = 'Both'";
		return $strWhere;
	}
		if($table=="System_preference" && $field=="default_disbursement_bank")
	{
		$strWhere = " type = 'Disbursement' or type = 'Both'";
		return $strWhere;
	}
		if($table=="System_preference" && $field=="default_ar")
	{
		$strWhere = " `General Clasification` = 'Current Assets' ";
		return $strWhere;
	}
		if($table=="System_preference" && $field=="default_ap")
	{
		$strWhere = " `General Clasification` = 'Current Liabilities' ";
		return $strWhere;
	}
		if($table=="ppe_list" && $field=="vat_type")
	{
		$strWhere = "purchase_only =1 ";
		return $strWhere;
	}
		if($table=="reimbursement" && $field=="checked_by")
	{
		$strWhere = "transaction = 9 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="reimbursement" && $field=="approved_by")
	{
		$strWhere = "transaction = 9 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="reimbursement_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="quotation" && $field=="Business_Partner")
	{
		$strWhere = "(business_partner.`type` = 'Customer') OR   (business_partner.`type` = 'Opportunity') OR   (business_partner.`type` = 'Customer and Supplier') OR   (business_partner.`type` = 'Leads')";
		return $strWhere;
	}
		if($table=="quotation" && $field=="checked_by")
	{
		$strWhere = "transaction = 8 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="quotation" && $field=="approved_by")
	{
		$strWhere = "transaction = 8 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="production" && $field=="approved_by")
	{
		$strWhere = "transaction = 22 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="production" && $field=="checked_by")
	{
		$strWhere = "transaction = 22 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="issue" && $field=="approved_by")
	{
		$strWhere = "transaction = 13 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="issue" && $field=="checked_by")
	{
		$strWhere = "transaction = 13 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="disposed" && $field=="approved_by")
	{
		$strWhere = "transaction = 24 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="disposed" && $field=="checked_by")
	{
		$strWhere = "transaction = 24 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="backload" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Customer'  Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="backload" && $field=="approved_by")
	{
		$strWhere = "transaction = 16 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="backload" && $field=="checked_by")
	{
		$strWhere = "transaction = 16 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="backload_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="trip_ticket" && $field=="approved_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="trip_ticket" && $field=="checked_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="fixed_assets_return" && $field=="approved_by")
	{
		$strWhere = "transaction = 15 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="fixed_assets_return" && $field=="checked_by")
	{
		$strWhere = "transaction = 15 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="cash_disbursement_detail2" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="cash_receipt_detail2" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="petty_cash" && $field=="approved_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="petty_cash" && $field=="checked_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="petty_cash" && $field=="default_vat_type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="petty_cash_detail" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1 ";
		return $strWhere;
	}
		if($table=="center_replenishment" && $field=="approved_by")
	{
		$strWhere = "transaction = 25 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="center_replenishment" && $field=="checked_by")
	{
		$strWhere = "transaction = 25 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="center_replenishment_detail" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="credit_memo" && $field=="checked_by")
	{
		$strWhere = "transaction = 6 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="credit_memo" && $field=="approved_by")
	{
		$strWhere = "transaction = 6 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="credit_memo_detail" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0 ";
		return $strWhere;
	}
		if($table=="debit_memo" && $field=="approved_by")
	{
		$strWhere = "transaction = 7 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="debit_memo" && $field=="checked_by")
	{
		$strWhere = "transaction = 7 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="project_replenishment" && $field=="approved_by")
	{
		$strWhere = "transaction = 21 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="project_replenishment" && $field=="checked_by")
	{
		$strWhere = "transaction = 21 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="project_replenishment_detail" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="sales" && $field=="checked_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="sales" && $field=="approved_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="sales" && $field=="default_vat_type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="sales_detail" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="purchase_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="dr_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="purchase_order_detail" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only =1";
		return $strWhere;
	}
		if($table=="project_replenishment_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="project_replenishment_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="center_replenishment_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="center_replenishment_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="purchase_order_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only =1";
		return $strWhere;
	}
		if($table=="purchase_order_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only =1";
		return $strWhere;
	}
		if($table=="purchase_order_receiving_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only =1";
		return $strWhere;
	}
		if($table=="purchase_order_receiving_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only =1";
		return $strWhere;
	}
		if($table=="dr_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="dr_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="petty_cash_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1 ";
		return $strWhere;
	}
		if($table=="petty_cash_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 1 ";
		return $strWhere;
	}
		if($table=="credit_memo_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0 ";
		return $strWhere;
	}
		if($table=="credit_memo_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0 ";
		return $strWhere;
	}
		if($table=="Purchases_for_checking" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchases_for_approval" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Sales_for_checking" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Customer'  Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Sales_for_approval" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Customer'  Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="credit_sales_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="credit_sales_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_for_checking" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_for_checking" && $field=="bank")
	{
		$strWhere = " type = 'Disbursment' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="check_voucher_detail2_for_checking" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_for_approval" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_for_approval" && $field=="bank")
	{
		$strWhere = " type = 'Disbursment' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="check_voucher_detail2_for_approval" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="estimate" && $field=="Business_Partner")
	{
		$strWhere = "(business_partner.`type` = 'Customer') OR   (business_partner.`type` = 'Opportunity') OR   (business_partner.`type` = 'Customer and Supplier') OR   (business_partner.`type` = 'Leads')";
		return $strWhere;
	}
		if($table=="estimate" && $field=="checked_by")
	{
		$strWhere = "transaction = 29 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="estimate" && $field=="approved_by")
	{
		$strWhere = "transaction = 29 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="estimate_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="purchase_request" && $field=="approved_by")
	{
		$strWhere = "transaction = 30 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase_request" && $field=="checked_by")
	{
		$strWhere = "transaction = 30 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="purchase_request" && $field=="supplier")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="purchase_request_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="inventory_adj" && $field=="checked_by")
	{
		$strWhere = "transaction = 5 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="inventory_adj" && $field=="approved_by")
	{
		$strWhere = "transaction = 5 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="inventory_tranfer" && $field=="approved_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="inventory_tranfer" && $field=="checked_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Customers" && $field=="default_sales_vat_type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="Suppliers" && $field=="default_purchase_vat_type")
	{
		$strWhere = " purchase_only = 1";
		return $strWhere;
	}
		if($table=="Inventory_Adjustment_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 6 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Inventory_Adjustment_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 6 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Inventory_Adjustment_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 6 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Inventory_Adjustment_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 6 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Estimate_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 33 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Estimate_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 33 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Estimate_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 33 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Estimate_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 33 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="estimate_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="estimate_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="production_request" && $field=="approved_by")
	{
		$strWhere = "transaction = 30 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="production_request" && $field=="checked_by")
	{
		$strWhere = "transaction = 30 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Credit_Card_monitoring" && $field=="bank")
	{
		$strWhere = " type = 'Receipt' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Credit_Card_monitoring" && $field=="checked_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Credit_Card_monitoring" && $field=="approved_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Request_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Request_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="purchase_request_detail_approval" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="Production_Request_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Production_Request_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Inventory_Transfer_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Inventory_Transfer_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Purchase_Request_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Request_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Production_Request_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Production_Request_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Inventory_Transfer_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Inventory_Transfer_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Backload_for_approval" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Customer'  Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Backload_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 18 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="backload_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="Backload_for_checking" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Customer'  Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="backload_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="Cash_Receipt_for_approval" && $field=="bank")
	{
		$strWhere = " type = 'Receipt' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Cash_Receipt_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Cash_Receipt_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Cash_Receipt_for_checking" && $field=="bank")
	{
		$strWhere = " type = 'Receipt' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Service_Report_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 11 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Service_Report_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 11 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Service_Report_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 11 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Service_Report_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 11 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="service_report_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only =0 ";
		return $strWhere;
	}
		if($table=="service_report_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only =0 ";
		return $strWhere;
	}
		if($table=="return" && $field=="approved_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="return" && $field=="checked_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="fixed_asset_issue" && $field=="approved_by")
	{
		$strWhere = "transaction = 14 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="fixed_asset_issue" && $field=="checked_by")
	{
		$strWhere = "transaction = 14 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="purchase_request_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="trip_ticket_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="trip_ticket_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="trip_ticket_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="trip_ticket_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Collection_Report_per_Customer" && $field=="bank")
	{
		$strWhere = " type = 'Receipt' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Payment_per_Supplier_Report" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Payment_per_Supplier_Report" && $field=="bank")
	{
		$strWhere = " type = 'Disbursement' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Purchase_Report" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchase_Report_per_BP" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchase_Report_per_Item" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchase_Report_per_Cost_Center" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchase_Report_per_BP_detail" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchase_Report_per_Item_detail" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchase_Report_per_Cost_Center_detail" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Production_Costing_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Production_Costing_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="quality_control" && $field=="checked_by")
	{
		$strWhere = "transaction = 52 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="quality_control" && $field=="approved_by")
	{
		$strWhere = "transaction = 52 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="budget" && $field=="checked_by")
	{
		$strWhere = "transaction = 41 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="budget" && $field=="approved_by")
	{
		$strWhere = "transaction = 41 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="sales_order" && $field=="checked_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="sales_order" && $field=="approved_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="sales_order_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="marketing_request_form" && $field=="approved_by")
	{
		$strWhere = "transaction = 45 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="marketing_request_form" && $field=="check_by")
	{
		$strWhere = "transaction = 45 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Quotation_Dashboard_Customer" && $field=="Business_Partner")
	{
		$strWhere = "type  <> 'Supplier'  ";
		return $strWhere;
	}
		if($table=="Quotation_Dashboard_Customer" && $field=="checked_by")
	{
		$strWhere = "transaction = 9 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Quotation_Dashboard_Customer" && $field=="approved_by")
	{
		$strWhere = "transaction = 9 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Delivery_Receipt_Dashboard_Customer" && $field=="approved_by")
	{
		$strWhere = "transaction = 13 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Delivery_Receipt_Dashboard_Customer" && $field=="checked_by")
	{
		$strWhere = "transaction = 13 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Delivery_Receipt_Dashboard_Customer" && $field=="driver")
	{
		$strWhere = " type = 'Employee'";
		return $strWhere;
	}
		if($table=="Sales_Dashboard_Customer" && $field=="checked_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Sales_Dashboard_Customer" && $field=="approved_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Backload_Dashboard_Customer" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Customer'  Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Backload_Dashboard_Customer" && $field=="approved_by")
	{
		$strWhere = "transaction = 18 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Backload_Dashboard_Customer" && $field=="checked_by")
	{
		$strWhere = "transaction = 18 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Purchase_Request_Dashboard_Supplier" && $field=="approved_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Request_Dashboard_Supplier" && $field=="checked_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Purchase_Order_Dashboard_Supplier" && $field=="approved_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Order_Dashboard_Supplier" && $field=="checked_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Purchase_Dashboard_Supplier" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Purchase_Dashboard_Supplier" && $field=="approved_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Dashboard_Supplier" && $field=="checked_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Checker' ";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="bank")
	{
		$strWhere = " type = 'Disbursement' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="checked_by")
	{
		$strWhere = "transaction = 4 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="approved_by")
	{
		$strWhere = "transaction = 4 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Debit_Memo_Dashboard_Supplier" && $field=="approved_by")
	{
		$strWhere = "transaction = 8 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Debit_Memo_Dashboard_Supplier" && $field=="checked_by")
	{
		$strWhere = "transaction = 8 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Purchase_Request_Dashboard_Item" && $field=="approved_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Request_Dashboard_Item" && $field=="checked_by")
	{
		$strWhere = "transaction = 34 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Purchase_Order_Dashboard_Item" && $field=="approved_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Order_Dashboard_Item" && $field=="checked_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Production_Dashboard_Item" && $field=="approved_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Production_Dashboard_Item" && $field=="checked_by")
	{
		$strWhere = "transaction = 26 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Deposit_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Deposit_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Open_Trip_Ticket_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Open_Trip_Ticket_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Deposit_in_transit_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Deposit_in_transit_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Outstanding_Checks_Report" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="Outstanding_Checks_Report" && $field=="bank")
	{
		$strWhere = " type = 'Disbursement' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Outstanding_Checks_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 4 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Outstanding_Checks_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 4 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="sales_per_sales_rep_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="sales_per_sales_rep_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Quotation_Dashboard" && $field=="Business_Partner")
	{
		$strWhere = "type  <> 'Supplier'  ";
		return $strWhere;
	}
		if($table=="Quotation_Dashboard" && $field=="checked_by")
	{
		$strWhere = "transaction = 9 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Quotation_Dashboard" && $field=="approved_by")
	{
		$strWhere = "transaction = 9 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Sales_Order_Dashboard" && $field=="checked_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Sales_Order_Dashboard" && $field=="approved_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Reimbursement_Dashboard" && $field=="checked_by")
	{
		$strWhere = "transaction = 10 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Reimbursement_Dashboard" && $field=="approved_by")
	{
		$strWhere = "transaction = 10 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="request_for_payment" && $field=="approved_by")
	{
		$strWhere = "transaction = 39 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="request_for_payment" && $field=="checked_by")
	{
		$strWhere = "transaction = 39 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="request_for_payment_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="quotation_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="issue_components" && $field=="approved_by")
	{
		$strWhere = "transaction = 48 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="issue_components" && $field=="checked_by")
	{
		$strWhere = "transaction = 48 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="disposed_inv" && $field=="approved_by")
	{
		$strWhere = "transaction = 53 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="disposed_inv" && $field=="checked_by")
	{
		$strWhere = "transaction = 24 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="production_request_report" && $field=="approved_by")
	{
		$strWhere = "transaction = 44 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="production_request_report" && $field=="checked_by")
	{
		$strWhere = "transaction = 44 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="approved_sales_order" && $field=="ref_no")
	{
		$strWhere = "Status = 'Approved'";
		return $strWhere;
	}
		if($table=="approved_sales_order" && $field=="prepared_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="approved_sales_order" && $field=="checked_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="approved_sales_order" && $field=="approved_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase_order_for_receiving" && $field=="approved_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase_order_for_receiving" && $field=="checked_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Cheker'";
		return $strWhere;
	}
		if($table=="packing_list" && $field=="checked_by")
	{
		$strWhere = "transaction = 25 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="packing_list" && $field=="approved_by")
	{
		$strWhere = "transaction = 54 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="purchase_order_receiving_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="approved_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="checked_by")
	{
		$strWhere = "transaction = 36 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="issue_components_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 48 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="issue_components_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 48 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="issue_components_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 48 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="issue_components_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 48 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="cash_sales_Report" && $field=="bank")
	{
		$strWhere = " type = 'Receipt' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="cash_sales_Report" && $field=="ref_no")
	{
		$strWhere = "Status = 'Approved'";
		return $strWhere;
	}
		if($table=="cash_sales_Report" && $field=="checked_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="cash_sales_Report" && $field=="approved_by")
	{
		$strWhere = "transaction = 35 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="Collection_Report_per_Sales_Rep" && $field=="bank")
	{
		$strWhere = " type = 'Receipt' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="marketing_request_form_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 45 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="marketing_request_form_for_checking" && $field=="check_by")
	{
		$strWhere = "transaction = 45 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="marketing_request_form_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 45 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="marketing_request_form_for_approval" && $field=="check_by")
	{
		$strWhere = "transaction = 45 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="production_per_item" && $field=="approved_by")
	{
		$strWhere = "transaction = 22 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="production_per_item" && $field=="checked_by")
	{
		$strWhere = "transaction = 22 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="DR_per_Item" && $field=="approved_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="DR_per_Item" && $field=="checked_by")
	{
		$strWhere = "transaction = 12 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="DR_per_Item" && $field=="driver")
	{
		$strWhere = " type = 'Employee'";
		return $strWhere;
	}
		if($table=="Logistic_Open_Trip_Ticket" && $field=="checked_by")
	{
		$strWhere = "transaction = 19 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="logistic_open_inventory_tranfer" && $field=="approved_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="logistic_open_inventory_tranfer" && $field=="checked_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="request_for_quote" && $field=="approved_by")
	{
		$strWhere = "transaction = 47 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="request_for_quote" && $field=="checked_by")
	{
		$strWhere = "transaction = 47 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="request_for_quoter_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="request_for_quote_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 47 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="request_for_quote_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 47 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="request_for_quote_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 47 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="request_for_quote_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 47 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Setup_Wizard" && $field=="default_receipt_bank")
	{
		$strWhere = " type = 'Receipt' or type = 'Both'";
		return $strWhere;
	}
		if($table=="Setup_Wizard" && $field=="default_disbursement_bank")
	{
		$strWhere = " type = 'Disbursement' or type = 'Both'";
		return $strWhere;
	}
		if($table=="Check_Release" && $field=="bank")
	{
		$strWhere = " type = 'Disbursement' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="Check_Release" && $field=="checked_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="Check_Release" && $field=="approved_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="canvas" && $field=="approved_by")
	{
		$strWhere = "transaction = 30 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="canvas" && $field=="checked_by")
	{
		$strWhere = "transaction = 30 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="canvas_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="inventory_tranfer_request" && $field=="approved_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="inventory_tranfer_request" && $field=="checked_by")
	{
		$strWhere = "transaction = 1 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="branch_sales" && $field=="default_vat_type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="branch_sales_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="inventory_tranfer_view" && $field=="approved_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="inventory_tranfer_view" && $field=="checked_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="picklist" && $field=="checked_by")
	{
		$strWhere = "transaction = 59 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="picklist" && $field=="approved_by")
	{
		$strWhere = "transaction = 56 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="picklist" && $field=="default_vat_type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="picklist_detail" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="projects" && $field=="vat_type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="picklist_for_approval" && $field=="checked_by")
	{
		$strWhere = "transaction = 59 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="picklist_for_approval" && $field=="approved_by")
	{
		$strWhere = "transaction = 59 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="picklist_for_approval" && $field=="default_vat_type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="picklist_for_checking" && $field=="checked_by")
	{
		$strWhere = "transaction = 59 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="picklist_for_checking" && $field=="approved_by")
	{
		$strWhere = "transaction = 59 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="picklist_for_checking" && $field=="default_vat_type")
	{
		$strWhere = "purchase_only =0";
		return $strWhere;
	}
		if($table=="picklist_detail_for_approval" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="picklist_detail_for_checking" && $field=="VAT_Type")
	{
		$strWhere = " purchase_only = 0";
		return $strWhere;
	}
		if($table=="open_production" && $field=="approved_by")
	{
		$strWhere = "transaction = 22 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="open_production" && $field=="checked_by")
	{
		$strWhere = "transaction = 22 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="project_name" && $field=="checked_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="project_name" && $field=="approved_by")
	{
		$strWhere = "transaction = 27 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="inventory_tranfer_mobile" && $field=="approved_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="inventory_tranfer_mobile" && $field=="checked_by")
	{
		$strWhere = "transaction = 32 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="item_with_balances" && $field=="Vat Type")
	{
		$strWhere = "purchase_only = 0";
		return $strWhere;
	}
		if($table=="item_with_balances" && $field=="purchase_vat_type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="asset_accountability" && $field=="approved_by")
	{
		$strWhere = "type = 'Approver'";
		return $strWhere;
	}
		if($table=="cash_pullout" && $field=="approved_by")
	{
		$strWhere = "type = 'Approver'";
		return $strWhere;
	}
		if($table=="liquidation" && $field=="Business_Partner")
	{
		$strWhere = " type = 'Supplier' Or  type = 'Customer and Supplier' Or  type = 'Employee' ";
		return $strWhere;
	}
		if($table=="liquidation" && $field=="checked_by")
	{
		$strWhere = "transaction = 68 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="liquidation" && $field=="approved_by")
	{
		$strWhere = "transaction = 68 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="liquidation_detail" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="marketing_job_order" && $field=="approved_by")
	{
		$strWhere = "type = 'Approver'";
		return $strWhere;
	}
		if($table=="spoilage" && $field=="approved_by")
	{
		$strWhere = "type = 'Approver'";
		return $strWhere;
	}
		if($table=="tara_sheet" && $field=="approved_by")
	{
		$strWhere = "type = 'Approver'";
		return $strWhere;
	}
		if($table=="canvass" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="canvass_for_checking" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="canvass_for_approval" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="canvass_to_purchase_order" && $field=="VAT_Type")
	{
		$strWhere = "purchase_only = 1";
		return $strWhere;
	}
		if($table=="open_cv_for_por" && $field=="bank")
	{
		$strWhere = " type = 'Disbursement' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="open_cv_for_por" && $field=="checked_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="open_cv_for_por" && $field=="approved_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="open_cv_for_por" && $field=="default_vat_type")
	{
		$strWhere = " purchase_only =1 ";
		return $strWhere;
	}
		if($table=="open_cv_for_liq" && $field=="bank")
	{
		$strWhere = " type = 'Disbursement' or  type = 'Both'";
		return $strWhere;
	}
		if($table=="open_cv_for_liq" && $field=="checked_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Checker'";
		return $strWhere;
	}
		if($table=="open_cv_for_liq" && $field=="approved_by")
	{
		$strWhere = "transaction = 3 AND  type = 'Approver'";
		return $strWhere;
	}
		if($table=="open_cv_for_liq" && $field=="default_vat_type")
	{
		$strWhere = " purchase_only =1 ";
		return $strWhere;
	}
	return "";
}

/**
 * @intellisense
 */
function GetDefaultValue($field, $ptype, $table="")
{
	global $strTableName;
	if(!$table)
		$table=$strTableName;
				if($table=="business_partner" && $field=="type")
	{
		return "Customer";
	}
				if($table=="business_partner" && $field=="inactive")
	{
		return 0;
	}
				if($table=="item" && $field=="Default Cost Price")
	{
		return 0;
	}
				if($table=="item" && $field=="Vat Type")
	{
		return "VATable";
	}
				if($table=="item" && $field=="Vat Rate")
	{
		return 12;
	}
				if($table=="item" && $field=="perpetual_method")
	{
		return 0;
	}
				if($table=="item" && $field=="automate_depreciation")
	{
		return 0;
	}
				if($table=="item" && $field=="inactive")
	{
		return 0;
	}
				if($table=="item" && $field=="purchase_vat_type")
	{
		return "Purchase of Goods";
	}
				if($table=="item" && $field=="purchase_vat_rate")
	{
		return 12;
	}
				if($table=="credit_terms" && $field=="Discount Percentage")
	{
		return 0;
	}
				if($table=="credit_terms" && $field=="Discount Days")
	{
		return 0;
	}
				if($table=="credit_terms" && $field=="Due Days")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="cash_receipt" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="EWT_Amount")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="cash_receipt" && $field=="vatable")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="collection_discount")
	{
		return 0;
	}
				if($table=="cash_receipt" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="purchase" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="purchase" && $field=="Terms_Discount_percent")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Terms_Discount_days")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Terms_due_date")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Due_Date")
	{
		return now();
	}
				if($table=="purchase" && $field=="Gross_Purchase")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="purchase" && $field=="EWT_Amount")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Net_Amount")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="purchase" && $field=="vatable")
	{
		return 0;
	}
				if($table=="purchase" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="purchase" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="cash_disbursment" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="cash_disbursment" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="cash_disbursment" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="cash_disbursment" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="cash_disbursment" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="cash_disbursment" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="cash_disbursment" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="cash_disbursment" && $field=="payable_discount")
	{
		return 0;
	}
				if($table=="cash_disbursment" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="cash_disbursment" && $field=="importation")
	{
		return 0;
	}
				if($table=="cash_disbursment" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="cash_disbursment" && $field=="payment_method")
	{
		return 1;
	}
				if($table=="cash_disbursment" && $field=="Transaction_Date")
	{
		return Now();
	}
				if($table=="general_journal" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="general_journal" && $field=="taxable")
	{
		return 1;
	}
				if($table=="beg_bal" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="bank" && $field=="type")
	{
		return "Both";
	}
				if($table=="bank" && $field=="default")
	{
		return 0;
	}
				if($table=="bank" && $field=="service_charge")
	{
		return 0;
	}
				if($table=="accounting_period" && $field=="open")
	{
		return 0;
	}
				if($table=="bank_recon" && $field=="statement_balance_date")
	{
		return Now();
	}
				if($table=="deposit" && $field=="transadate")
	{
		return Now();
	}
				if($table=="recon_CR" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="recon_CR" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="recon_CR" && $field=="vatable")
	{
		return 0;
	}
				if($table=="recon_CR" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="recon_CR" && $field=="date_cleared")
	{
		return date('Y-m-d');;
	}
				if($table=="Recon_deposit" && $field=="transadate")
	{
		return now();
	}
				if($table=="Recon_deposit" && $field=="date_cleared")
	{
		return date('Y-m-d');;
	}
				if($table=="Recon_CV" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Recon_CV" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Recon_CV" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Recon_CV" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Recon_CV" && $field=="date_cleared")
	{
		return date('Y-m-d');;
	}
				if($table=="Recon_GV_dep" && $field=="DateCleared")
	{
		return date('Y-m-d');;
	}
				if($table=="Recon_GV_CV" && $field=="DateCleared")
	{
		return date('Y-m-d');;
	}
				if($table=="dr" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="dr" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="dr" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="dr" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="dr" && $field=="types_of_dr")
	{
		return 'Normal Delivery';
	}
				if($table=="purchase_order" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="purchase_order" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="purchase_order" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="purchase_order" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="purchase_order" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="purchase_order" && $field=="invoice_date")
	{
		return Now();
	}
				if($table=="purchase_order" && $field=="delivery_status")
	{
		return 'Open';
	}
				if($table=="purchase_order_receiving" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="purchase_order_receiving" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="purchase_order_receiving" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="purchase_order_receiving" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="purchase_order_receiving" && $field=="release_date")
	{
		return Now();
	}
				if($table=="purchase_order_receiving" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="System_preference" && $field=="accouting_period")
	{
		return "Calendar";
	}
				if($table=="System_preference" && $field=="fiscal_month_end")
	{
		return 12;
	}
				if($table=="System_preference" && $field=="allow_pre_period_posting")
	{
		return 0;
	}
				if($table=="System_preference" && $field=="use_undeposited_account")
	{
		return 0;
	}
				if($table=="System_preference" && $field=="category")
	{
		return "Private";
	}
				if($table=="ppe_list" && $field=="start_depreciation_date")
	{
		return Now();
	}
				if($table=="ppe_list" && $field=="warranty_date")
	{
		return Now();
	}
				if($table=="meetings" && $field=="date")
	{
		return Now();
	}
				if($table=="meetings" && $field=="status")
	{
		return "Planned";
	}
				if($table=="meetings" && $field=="done")
	{
		return 0;
	}
				if($table=="calls" && $field=="date")
	{
		return Now();
	}
				if($table=="calls" && $field=="status")
	{
		return "Planned";
	}
				if($table=="campaign" && $field=="start_date")
	{
		return Now();
	}
				if($table=="campaign" && $field=="end_date")
	{
		return Now();
	}
				if($table=="reimbursement" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="reimbursement" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="reimbursement" && $field=="Discount_Account")
	{
		return "Purchase Discount";
	}
				if($table=="reimbursement" && $field=="VAT_Account")
	{
		return "Input Vat";
	}
				if($table=="reimbursement" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="reimbursement_detail" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="reimbursement_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="Target_customers" && $field=="inactive")
	{
		return 0;
	}
				if($table=="quotation" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="quotation" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="case" && $field=="status")
	{
		return "Open";
	}
				if($table=="case" && $field=="date_of_purchase")
	{
		return Now();
	}
				if($table=="production" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="production" && $field=="production_status")
	{
		return Done;
	}
				if($table=="issue" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="issue_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="disposed" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="disposed" && $field=="date_needed")
	{
		return Now();
	}
				if($table=="disposed_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="backload" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="backload" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="backload" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="backload" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="backload" && $field=="Net_Amount")
	{
		return 0;
	}
				if($table=="backload" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="backload" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="backload_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="backload_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="backload_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="vehicle" && $field=="reg_date")
	{
		return Now();
	}
				if($table=="vehicle" && $field=="available")
	{
		return 0;
	}
				if($table=="trip_ticket" && $field=="date_added")
	{
		return Now();
	}
				if($table=="trip_ticket" && $field=="loaded")
	{
		return 0;
	}
				if($table=="approver_list" && $field=="type")
	{
		return Checker;
	}
				if($table=="fixed_asset_return_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="fixed_assets_return" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="fixed_assets_return" && $field=="date_of_request")
	{
		return now();
	}
				if($table=="fixed_assets_return" && $field=="date_of_return")
	{
		return now();
	}
				if($table=="Prospect_customers" && $field=="inactive")
	{
		return 0;
	}
				if($table=="Prospect_customers" && $field=="next_action_date")
	{
		return Now();
	}
				if($table=="trip_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="cash_disbursement_detail2" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="cash_disbursement_detail2" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="cash_disbursement_detail2" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="cash_disbursement_detail2" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="cash_disbursment_detail" && $field=="vatable")
	{
		return 0;
	}
				if($table=="cash_disbursment_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="cash_receipt_detail" && $field=="Amount Paid")
	{
		return 0;
	}
				if($table=="cash_receipt_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="cash_receipt_detail" && $field=="amount_paid_fc")
	{
		return 0;
	}
				if($table=="cash_receipt_detail2" && $field=="Amount")
	{
		return 0;
	}
				if($table=="cash_receipt_detail2" && $field=="VAT_Type")
	{
		return "Non VATable";
	}
				if($table=="cash_receipt_detail2" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="cash_receipt_detail2" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="cash_receipt_detail2" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="general_journal_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="employee_list" && $field=="inactive")
	{
		return 0;
	}
				if($table=="petty_cash" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="petty_cash" && $field=="Gross_Purchase")
	{
		return 0;
	}
				if($table=="petty_cash" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="petty_cash" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="petty_cash" && $field=="Net_Amount")
	{
		return 0;
	}
				if($table=="petty_cash" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="petty_cash" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="petty_cash" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="petty_cash_detail" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="petty_cash_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="petty_cash_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="petty_cash_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="center_replenishment" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="center_replenishment" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="center_replenishment" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="center_replenishment_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="center_replenishment_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="center_replenishment_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="credit_memo" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="credit_memo" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="credit_memo" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="credit_memo" && $field=="currency")
	{
		return "Peso";
	}
				if($table=="credit_memo_detail" && $field=="Qty")
	{
		return 0;
	}
				if($table=="credit_memo_detail" && $field=="VAT_Type")
	{
		return "Non VATable";
	}
				if($table=="credit_memo_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="credit_memo_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="credit_memo_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="debit_memo" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="debit_memo" && $field=="Payable_Account")
	{
		return 'Purchase Discount';
	}
				if($table=="debit_memo" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="debit_memo" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="debit_memo" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="debit_memo_detail" && $field=="Qty")
	{
		return 0;
	}
				if($table=="debit_memo_detail" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="debit_memo_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="debit_memo_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="debit_memo_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="project_replenishment" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="project_replenishment" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="project_replenishment" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="project_replenishment_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="project_replenishment_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="project_replenishment_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="Sales_Representatives" && $field=="inactive")
	{
		return 0;
	}
				if($table=="sales" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="sales" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="sales" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="sales" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="sales" && $field=="discount_rate")
	{
		return 0;
	}
				if($table=="sales" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="sales_detail" && $field=="VAT_Type")
	{
		return "Non VATable";
	}
				if($table=="sales_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="sales_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="tranasactions_for_approval" && $field=="default_status")
	{
		return "Approved";
	}
				if($table=="tranasactions_for_approval" && $field=="allow_edit_after_approval")
	{
		return 0;
	}
				if($table=="deposit_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="purchase_detail" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="purchase_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="purchase_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="purchase_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="dr_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="dr_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="dr_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="purchase_order_detail" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="purchase_order_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="purchase_order_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="purchase_order_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="Sales_Order_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Order_for_checking" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Sales_Order_for_checking" && $field=="currency")
	{
		return "Peso";
	}
				if($table=="Sales_Order_for_checking" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Sales_Order_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Order_for_approval" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Sales_Order_for_approval" && $field=="currency")
	{
		return "Peso";
	}
				if($table=="Sales_Order_for_approval" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Quotation_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Quotation_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Reimbursement_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Reimbursement_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Project_Replenishment_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Project_Replenishment_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_Order_for_checking2" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_Order_for_checking2" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Purchases_Order_for_approval2" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_Order_for_approval2" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Receiving_for_checking2" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Receiving_for_checking2" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Receiving_for_checking2" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Receiving_for_checking2" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Receiving_for_checking2" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Receiving_for_approval2" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Receiving_for_approval2" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Receiving_for_approval2" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Receiving_for_approval2" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Receiving_for_approval2" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Delivery_Receipt_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Delivery_Receipt_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Production_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Production_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Issue_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Issue_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Return_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Return_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Disposal_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Fixed_Asset_Issue_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Fixed_Asset_Issue_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Fixed_Asset_Return_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Fixed_Asset_Return_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Petty_Cash_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Petty_Cash_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Deposit_for_checking" && $field=="transadate")
	{
		return Now();
	}
				if($table=="Deposit_for_approval" && $field=="transadate")
	{
		return Now();
	}
				if($table=="Credit_Memo_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Credit_Memo_for_checking" && $field=="currency")
	{
		return "Peso";
	}
				if($table=="Credit_Memo_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Credit_Memo_for_approval" && $field=="currency")
	{
		return "Peso";
	}
				if($table=="Purchases_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_for_checking" && $field=="Terms_Discount_percent")
	{
		return 0;
	}
				if($table=="Purchases_for_checking" && $field=="Terms_Discount_days")
	{
		return 0;
	}
				if($table=="Purchases_for_checking" && $field=="Terms_due_date")
	{
		return 0;
	}
				if($table=="Purchases_for_checking" && $field=="Due_Date")
	{
		return now();
	}
				if($table=="Purchases_for_checking" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Purchases_for_checking" && $field=="vatable")
	{
		return 0;
	}
				if($table=="Purchases_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_for_approval" && $field=="Terms_Discount_percent")
	{
		return 0;
	}
				if($table=="Purchases_for_approval" && $field=="Terms_Discount_days")
	{
		return 0;
	}
				if($table=="Purchases_for_approval" && $field=="Terms_due_date")
	{
		return 0;
	}
				if($table=="Purchases_for_approval" && $field=="Due_Date")
	{
		return now();
	}
				if($table=="Purchases_for_approval" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Purchases_for_approval" && $field=="vatable")
	{
		return 0;
	}
				if($table=="Sales_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_for_checking" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Sales_for_checking" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Sales_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_for_approval" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Sales_for_approval" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="importation")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="currecy")
	{
		return 1;
	}
				if($table=="Cash_Disbursement_for_checking" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="check_voucher_detail_for_checking" && $field=="vatable")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="importation")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="currecy")
	{
		return 1;
	}
				if($table=="Cash_Disbursement_for_approval" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="check_voucher_detail_for_approval" && $field=="vatable")
	{
		return 0;
	}
				if($table=="General_Journal_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="General_Journal_for_checking" && $field=="taxable")
	{
		return 1;
	}
				if($table=="General_Journal_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="General_Journal_for_approval" && $field=="taxable")
	{
		return 1;
	}
				if($table=="for_submissions" && $field=="due_date")
	{
		return Now();
	}
				if($table=="submission_details" && $field=="side")
	{
		return "Front";
	}
				if($table=="estimate" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="estimate" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="estimate_detail" && $field=="VAT_Type")
	{
		return "Non VATable";
	}
				if($table=="estimate_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="estimate_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="estimate_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="purchase_request" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="purchase_request" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="purchase_request" && $field=="Gross_Purchase")
	{
		return 0;
	}
				if($table=="purchase_request" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="purchase_request" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="purchase_request" && $field=="Net_Amount")
	{
		return 0;
	}
				if($table=="purchase_request" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="purchase_request" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="purchase_request" && $field=="is_rushed")
	{
		return 0;
	}
				if($table=="purchase_request" && $field=="delivery_date")
	{
		return Now();
	}
				if($table=="purchase_request" && $field=="date_last_purchase")
	{
		return Now();
	}
				if($table=="purchase_request_detail" && $field=="Amount")
	{
		return 0;
	}
				if($table=="purchase_request_detail" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="purchase_request_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="purchase_request_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="purchase_request_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="inv_adj_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="inventory_adj" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="inventory_adj" && $field=="gl_adjustment_account")
	{
		return 68;
	}
				if($table=="inventory_tranfer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="inventory_tranfer" && $field=="currency")
	{
		return 2;
	}
				if($table=="inventory_tranfer" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="inventory_transfer_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="Customers" && $field=="type")
	{
		return "Customer";
	}
				if($table=="Customers" && $field=="inactive")
	{
		return 0;
	}
				if($table=="Suppliers" && $field=="type")
	{
		return "Supplier";
	}
				if($table=="Suppliers" && $field=="inactive")
	{
		return 0;
	}
				if($table=="Suppliers" && $field=="primary_revenue_type")
	{
		return "Seller of Goods";
	}
				if($table=="Statement_of_Account" && $field=="type")
	{
		return "Customer";
	}
				if($table=="Statement_of_Account" && $field=="inactive")
	{
		return 0;
	}
				if($table=="Inventory_Adjustment_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Inventory_Adjustment_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Estimate_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Estimate_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Follow_up" && $field=="type")
	{
		return "Customer";
	}
				if($table=="Follow_up" && $field=="inactive")
	{
		return 0;
	}
				if($table=="coming_meetings" && $field=="date")
	{
		return Now();
	}
				if($table=="coming_meetings" && $field=="status")
	{
		return "Planned";
	}
				if($table=="coming_meetings" && $field=="done")
	{
		return 0;
	}
				if($table=="Prospect_customers_to_Customer" && $field=="inactive")
	{
		return 0;
	}
				if($table=="production_request" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="production_request_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="Credit_Card_monitoring" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Credit_Card_monitoring" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Credit_Card_monitoring" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Credit_Card_monitoring" && $field=="EWT_Amount")
	{
		return 0;
	}
				if($table=="Credit_Card_monitoring" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Credit_Card_monitoring" && $field=="vatable")
	{
		return 0;
	}
				if($table=="Credit_Card_monitoring" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Credit_Card_monitoring" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="Purchase_Request_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_for_approval" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Production_Request_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Inventory_Transfer_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_for_checking" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Production_Request_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Inventory_Transfer_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Backload_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Backload_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Cash_Receipt_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Cash_Receipt_for_approval" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="EWT_Amount")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="vatable")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_approval" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Cash_Receipt_for_checking" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="EWT_Amount")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="vatable")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Cash_Receipt_for_checking" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="Service_Report_for_approval" && $field=="date_attended")
	{
		return Now();
	}
				if($table=="Service_Report_for_checking" && $field=="date_attended")
	{
		return Now();
	}
				if($table=="return" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="return" && $field=="datetime")
	{
		return Now();
	}
				if($table=="return" && $field=="datetime1")
	{
		return Now();
	}
				if($table=="return" && $field=="datetime2")
	{
		return Now();
	}
				if($table=="return_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="return_detail" && $field=="date")
	{
		return Now();
	}
				if($table=="fixed_asset_issue" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="fixed_asset_issue" && $field=="date_of_request")
	{
		return Now();
	}
				if($table=="fixed_asset_issue_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="cash_disbursment_detail_for_approval" && $field=="vatable")
	{
		return 0;
	}
				if($table=="cash_disbursment_detail_for_checking" && $field=="vatable")
	{
		return 0;
	}
				if($table=="trip_ticket_for_approval" && $field=="date_added")
	{
		return Now();
	}
				if($table=="trip_ticket_for_approval" && $field=="loaded")
	{
		return 0;
	}
				if($table=="trip_ticket_for_checking" && $field=="date_added")
	{
		return Now();
	}
				if($table=="trip_ticket_for_checking" && $field=="loaded")
	{
		return 0;
	}
				if($table=="trip_detail_for_approval" && $field=="from_date")
	{
		return Now();
	}
				if($table=="trip_detail_for_approval" && $field=="to date")
	{
		return Now();
	}
				if($table=="trip_detail_for_checking" && $field=="from_date")
	{
		return Now();
	}
				if($table=="trip_detail_for_checking" && $field=="to date")
	{
		return Now();
	}
				if($table=="sales_report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Collection_Report_per_Customer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Payment_per_Supplier_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Report_per_BP" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Report_per_Item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Report_per_Cost_Center" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Report_per_BP_detail" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Report_per_Item_detail" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Report_per_Cost_Center_detail" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Report_per_BP" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Report_per_Item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Report_per_Cost_Center" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Report_per_BP_detail" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Report_per_Item_detail" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Report_per_Cost_Center_detail" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Report_per_sales_rep" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Import_Costing" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Production_Costing_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Production_Costing_Report" && $field=="production_status")
	{
		return Done;
	}
				if($table=="Production_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Closed_Opportunities" && $field=="type")
	{
		return "Customer";
	}
				if($table=="Cases_with_Sotutions" && $field=="status")
	{
		return "Open";
	}
				if($table=="Totals_Cases_Created" && $field=="status")
	{
		return "Open";
	}
				if($table=="Totals_Open_Cases_by_Agent" && $field=="status")
	{
		return "Open";
	}
				if($table=="Campaign_Contacts" && $field=="start_date")
	{
		return Now();
	}
				if($table=="Campaign_Contacts" && $field=="end_date")
	{
		return Now();
	}
				if($table=="Campaign_leads" && $field=="start_date")
	{
		return Now();
	}
				if($table=="Campaign_leads" && $field=="end_date")
	{
		return Now();
	}
				if($table=="Campaign_Revenue" && $field=="start_date")
	{
		return Now();
	}
				if($table=="Campaign_Revenue" && $field=="end_date")
	{
		return Now();
	}
				if($table=="Opportunity_Schedule" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_by_Account" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_by_Lead_Source" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_by_Partner" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_by_Rep" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="DR_Reports" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Order_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Case_History" && $field=="status")
	{
		return "Open";
	}
				if($table=="quality_control" && $field=="date")
	{
		return Now();
	}
				if($table=="quality_control_detail" && $field=="purpose")
	{
		return 'For Delivery';
	}
				if($table=="quality_control_detail" && $field=="item_status")
	{
		return 'Good';
	}
				if($table=="quality_control_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="budget" && $field=="date")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance" && $field=="date_purchased")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance" && $field=="date")
	{
		return Now();
	}
				if($table=="production_form" && $field=="Delivery_Date")
	{
		return Now();
	}
				if($table=="rfp" && $field=="Date_Payment_Needed")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_detail" && $field=="date_of_prepare")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="marketing_colateral" && $field=="date_published")
	{
		return Now();
	}
				if($table=="email" && $field=="date")
	{
		return Now();
	}
				if($table=="sales_order" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="sales_order" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="sales_order" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="sales_order" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="sales_order" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="sales_order" && $field=="delivery_status")
	{
		return "Open";
	}
				if($table=="sales_order" && $field=="delivery_date")
	{
		return Now();
	}
				if($table=="sales_order_detail" && $field=="VAT_Type")
	{
		return "Non VATable";
	}
				if($table=="sales_order_detail" && $field=="billing_type")
	{
		return "One Time";
	}
				if($table=="sales_order_detail" && $field=="billing_start_date")
	{
		return Now('Y-m-d');
	}
				if($table=="sales_order_detail" && $field=="no_of_months")
	{
		return 1;
	}
				if($table=="sales_order_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="marketing_request_form" && $field=="date_requested")
	{
		return Now();
	}
				if($table=="marketing_request_form" && $field=="deadline_draft")
	{
		return Now();
	}
				if($table=="marketing_request_form" && $field=="deadline_final")
	{
		return Now();
	}
				if($table=="marketing_request_form" && $field=="actual_draft")
	{
		return Now();
	}
				if($table=="marketing_request_form" && $field=="actual_final")
	{
		return Now();
	}
				if($table=="Quotation_Dashboard_Customer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Order_Dashboard_Customer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Order_Dashboard_Customer" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Delivery_Receipt_Dashboard_Customer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Dashboard_Customer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Dashboard_Customer" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Sales_Dashboard_Customer" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Backload_Dashboard_Customer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_Dashboard_Supplier" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_Dashboard_Supplier" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Dashboard_Supplier" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Order_Dashboard_Supplier" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Dashboard_Supplier" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Purchase_Order_Dashboard_Supplier" && $field=="invoice_date")
	{
		return Now();
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="Terms_Discount_percent")
	{
		return 0;
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="Terms_Discount_days")
	{
		return 0;
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="Terms_due_date")
	{
		return 0;
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="Due_Date")
	{
		return now();
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Purchase_Dashboard_Supplier" && $field=="vatable")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="importation")
	{
		return 0;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="currecy")
	{
		return 1;
	}
				if($table=="Cash_Disbursement_Dashboard_Supplier" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Debit_Memo_Dashboard_Supplier" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_Dashboard_Item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Request_Dashboard_Item" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Dashboard_Item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Order_Dashboard_Item" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Dashboard_Item" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Purchase_Order_Dashboard_Item" && $field=="invoice_date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Item" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Item" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Item" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Item" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Production_Dashboard_Item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Production_Dashboard_Item" && $field=="production_status")
	{
		return Done;
	}
				if($table=="budget_for_approval" && $field=="date")
	{
		return Now();
	}
				if($table=="budget_for_checking" && $field=="date")
	{
		return Now();
	}
				if($table=="request_for_payment_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="request_for_payment_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_detail_for_approval" && $field=="date_of_prepare")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_for_approval" && $field=="date_purchased")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_for_approval" && $field=="date")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_for_checking" && $field=="date_purchased")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_for_checking" && $field=="date")
	{
		return Now();
	}
				if($table=="repairs_and_maintenance_detail_for_checking" && $field=="date_of_prepare")
	{
		return Now();
	}
				if($table=="Disposal_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Active_campaign_report" && $field=="start_date")
	{
		return Now();
	}
				if($table=="Active_campaign_report" && $field=="end_date")
	{
		return Now();
	}
				if($table=="For_Billing_report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="sales_order_for_project_mngmt" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="inventory_transfer_cost_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="inventory_transfer_cost_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Deposit_Report" && $field=="transadate")
	{
		return Now();
	}
				if($table=="SO_for_Billing_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Billing_due_dates_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Packing_List_Report" && $field=="delivery_date")
	{
		return Now();
	}
				if($table=="Open_Trip_Ticket_Report" && $field=="date_added")
	{
		return Now();
	}
				if($table=="Open_Trip_Ticket_Report" && $field=="loaded")
	{
		return 0;
	}
				if($table=="Transfer_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Open_Case_Report_s" && $field=="status")
	{
		return "Open";
	}
				if($table=="Sales_Order_per_Campaign_Report_marketing" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_per_campaign_Report_marketing" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Deposit_in_transit_Report" && $field=="transadate")
	{
		return Now();
	}
				if($table=="Outstanding_Checks_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Outstanding_Checks_Report" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Outstanding_Checks_Report" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Outstanding_Checks_Report" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Outstanding_Checks_Report" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Outstanding_Checks_Report" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Outstanding_Checks_Report" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="Outstanding_Checks_Report" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Outstanding_Checks_Report" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Outstanding_Checks_Report" && $field=="importation")
	{
		return 0;
	}
				if($table=="Outstanding_Checks_Report" && $field=="currecy")
	{
		return 1;
	}
				if($table=="Outstanding_Checks_Report" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Followup_Report" && $field=="type")
	{
		return "Customer";
	}
				if($table=="Followup_Report" && $field=="inactive")
	{
		return 0;
	}
				if($table=="Coming_Meeting_Report" && $field=="date")
	{
		return Now();
	}
				if($table=="Coming_Meeting_Report" && $field=="status")
	{
		return "Planned";
	}
				if($table=="Coming_Meeting_Report" && $field=="done")
	{
		return 0;
	}
				if($table=="Meeting_Report" && $field=="date")
	{
		return Now();
	}
				if($table=="Meeting_Report" && $field=="status")
	{
		return "Planned";
	}
				if($table=="Meeting_Report" && $field=="done")
	{
		return 0;
	}
				if($table=="Calls_Report" && $field=="date")
	{
		return Now();
	}
				if($table=="Calls_Report" && $field=="status")
	{
		return "Planned";
	}
				if($table=="sales_per_sales_rep_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="sales_per_sales_rep_Report" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="sales_per_sales_rep_Report" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="date_processed")
	{
		return Now();
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="period_from")
	{
		return Now();
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="period_to")
	{
		return Now();
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="annualized")
	{
		return 0;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="compute_phic")
	{
		return 1;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="compute_sss")
	{
		return 1;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="compute_pag-ibig")
	{
		return 1;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="compute_tax")
	{
		return 1;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="include_recurring_benefit")
	{
		return 1;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="include_recurring_deductions")
	{
		return 1;
	}
				if($table=="Withholding_Tax_Collection_List_per_Month_Report" && $field=="payroll_mode")
	{
		return "Semi-Monthly";
	}
				if($table=="cash_receipt_cost_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="cash_receipt_cost_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Quotation_Dashboard" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Order_Dashboard" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Order_Dashboard" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Sales_Order_Dashboard" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Reimbursement_Dashboard" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="request_for_payment" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="request_for_payment" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="request_for_payment" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="request_for_payment" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="request_for_payment" && $field=="date_needed")
	{
		return Now();
	}
				if($table=="request_for_payment_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="request_for_payment_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="request_for_payment_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="quotation_detail" && $field=="VAT_Type")
	{
		return "Non VATable";
	}
				if($table=="quotation_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="quotation_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="quotation_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="petty_cash_for_liquidation" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="item_cost_recalculation" && $field=="date")
	{
		return Now();
	}
				if($table=="item_cost_recalculation" && $field=="start_date")
	{
		return Now();
	}
				if($table=="item_cost_recalculation" && $field=="end_date")
	{
		return Now();
	}
				if($table=="issue_components" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="issue_components_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="demand_plan" && $field=="date")
	{
		return Now();
	}
				if($table=="input_vat_allocation" && $field=="date")
	{
		return Now();
	}
				if($table=="qc_inspection" && $field=="Rev_&_Date")
	{
		return Now();
	}
				if($table=="packing_list_for_checking" && $field=="delivery_date")
	{
		return Now();
	}
				if($table=="packing_list_for_approval" && $field=="delivery_date")
	{
		return Now();
	}
				if($table=="disposed_inv_detail" && $field=="expiry_date")
	{
		return Now();
	}
				if($table=="disposed_inv_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="disposed_inv" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Customer_For_Approval" && $field=="type")
	{
		return "Customer";
	}
				if($table=="Customer_For_Approval" && $field=="inactive")
	{
		return 0;
	}
				if($table=="credit_memo_report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="debit_memo_report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="production_request_report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="approved_sales_order" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="approved_sales_order" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="purchase_order_for_receiving" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="purchase_order_for_receiving" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="purchase_order_for_receiving" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="purchase_order_for_receiving" && $field=="release_date")
	{
		return Now();
	}
				if($table=="purchase_order_for_receiving" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="packing_list" && $field=="delivery_date")
	{
		return Now();
	}
				if($table=="packing_list_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="purchase_order_receiving_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Purchase_Order_Receiving_Dashboard_Supplier" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="monthly_consuption_for_production_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="issue_components_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="issue_components_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_Order_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_Order_for_checking" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Purchases_Order_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Purchases_Order_for_approval" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Receiving_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Receiving_for_checking" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Receiving_for_checking" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Receiving_for_checking" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Receiving_for_checking" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Receiving_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Receiving_for_approval" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Receiving_for_approval" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Receiving_for_approval" && $field=="release_date")
	{
		return Now();
	}
				if($table=="Receiving_for_approval" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="inventory_tranfer_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="cash_sales_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="cash_sales_Report" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="cash_sales_Report" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="cash_sales_Report" && $field=="EWT_Amount")
	{
		return 0;
	}
				if($table=="cash_sales_Report" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="cash_sales_Report" && $field=="vatable")
	{
		return 0;
	}
				if($table=="cash_sales_Report" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="cash_sales_Report" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="Center_Replenishment_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Center_Replenishment_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Production_Summary" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Production_Summary" && $field=="expiry_date")
	{
		return Now();
	}
				if($table=="quality_control_for_approval" && $field=="date")
	{
		return Now();
	}
				if($table=="quality_control_for_checking" && $field=="date")
	{
		return Now();
	}
				if($table=="Current_Accounts" && $field=="inactive")
	{
		return 0;
	}
				if($table=="Current_Accounts" && $field=="next_action_date")
	{
		return Now();
	}
				if($table=="Collection_Report_per_Sales_Rep" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_checking" && $field=="date_requested")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_checking" && $field=="deadline_draft")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_checking" && $field=="deadline_final")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_checking" && $field=="actual_draft")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_checking" && $field=="actual_final")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_approval" && $field=="date_requested")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_approval" && $field=="deadline_draft")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_approval" && $field=="deadline_final")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_approval" && $field=="actual_draft")
	{
		return Now();
	}
				if($table=="marketing_request_form_for_approval" && $field=="actual_final")
	{
		return Now();
	}
				if($table=="Business_Owner_Sales_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Business_Owner_Purchase_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Finance_approved_request_for_payment" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Finance_Approved_Employee_Loan" && $field=="date")
	{
		return Now();
	}
				if($table=="production_per_item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="production_per_item" && $field=="production_status")
	{
		return Done;
	}
				if($table=="DR_per_Item" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="DR_per_Item" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="Logistic_Open_Trip_Ticket" && $field=="date_added")
	{
		return Now();
	}
				if($table=="Marketing_Open_Campaign" && $field=="start_date")
	{
		return Now();
	}
				if($table=="Marketing_Open_Campaign" && $field=="end_date")
	{
		return Now();
	}
				if($table=="Support_Open_Case_Report" && $field=="status")
	{
		return "Open";
	}
				if($table=="Sale_Meeting_Report" && $field=="date")
	{
		return Now();
	}
				if($table=="Sale_Meeting_Report" && $field=="status")
	{
		return "Planned";
	}
				if($table=="Sale_Meeting_Report" && $field=="done")
	{
		return 0;
	}
				if($table=="Production_WIP" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="logistic_open_inventory_tranfer" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Sales_Leads" && $field=="type")
	{
		return "Customer";
	}
				if($table=="production_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="production_detail" && $field=="no_of_batches")
	{
		return 1;
	}
				if($table=="EWT_Certificates_summay" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="EWT_Certificates_summay" && $field=="EWT_Amount")
	{
		return 0;
	}
				if($table=="Recon_withdraw" && $field=="cleared_date")
	{
		return date('Y-m-d');;
	}
				if($table=="request_for_quote" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="request_for_quoter_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="request_for_quote_for_checking" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="request_for_quote_for_approval" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="estimate_cost" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="estimate_cost" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Setup_Wizard" && $field=="accouting_period")
	{
		return "Calendar";
	}
				if($table=="Setup_Wizard" && $field=="fiscal_month_end")
	{
		return 12;
	}
				if($table=="Setup_Wizard" && $field=="allow_pre_period_posting")
	{
		return 0;
	}
				if($table=="Setup_Wizard" && $field=="use_undeposited_account")
	{
		return 0;
	}
				if($table=="Setup_Wizard" && $field=="category")
	{
		return "Private";
	}
				if($table=="memorized_transactions" && $field=="start_date")
	{
		return now();
	}
				if($table=="Check_Release" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="Check_Release" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="Check_Release" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="Check_Release" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="Check_Release" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="Check_Release" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="Check_Release" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="Check_Release" && $field=="payable_discount")
	{
		return 0;
	}
				if($table=="Check_Release" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="Check_Release" && $field=="importation")
	{
		return 0;
	}
				if($table=="Check_Release" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="Check_Release" && $field=="Transaction_Date")
	{
		return Now();
	}
				if($table=="canvas" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="canvas" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="canvas" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="canvas" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="canvas_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="canvas_detail" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="canvas_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="inventory_tranfer_request" && $field=="Transadate")
	{
		return now();
	}
				if($table=="branch_sales" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="branch_sales" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="branch_sales" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="branch_sales" && $field=="rpoints")
	{
		return 0;
	}
				if($table=="branch_sales" && $field=="card_amount")
	{
		return 0;
	}
				if($table=="branch_sales" && $field=="card_number")
	{
		return 0;
	}
				if($table=="branch_sales_detail" && $field=="VAT_Type")
	{
		return "Non VATable";
	}
				if($table=="branch_sales_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="branch_sales_detail" && $field=="EWT_Rate")
	{
		return 0;
	}
				if($table=="inventory_tranfer_view" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="inventory_transfer_detail_view" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="expense" && $field=="date")
	{
		return Now();
	}
				if($table=="picklist" && $field=="Transadate")
	{
		return now();
	}
				if($table=="picklist" && $field=="Terms_Discount_percent")
	{
		return 0;
	}
				if($table=="picklist" && $field=="Terms_Discount_days")
	{
		return 0;
	}
				if($table=="picklist" && $field=="Terms_due_date")
	{
		return 0;
	}
				if($table=="picklist" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="picklist" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="picklist" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="picklist" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="picklist" && $field=="Net_Amount")
	{
		return 0;
	}
				if($table=="picklist" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="picklist" && $field=="vatable")
	{
		return 0;
	}
				if($table=="picklist_detail" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="picklist_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="projects" && $field=="expected_start_date")
	{
		return now();
	}
				if($table=="projects" && $field=="expected_finish_date")
	{
		return now();
	}
				if($table=="DR_Dashboard_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="inventory_tranfer_Dashboard_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="project_replenishment_Dashboard_Report" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="picklist_for_approval" && $field=="Transadate")
	{
		return now();
	}
				if($table=="picklist_for_approval" && $field=="Terms_Discount_percent")
	{
		return 0;
	}
				if($table=="picklist_for_approval" && $field=="Terms_Discount_days")
	{
		return 0;
	}
				if($table=="picklist_for_approval" && $field=="Terms_due_date")
	{
		return 0;
	}
				if($table=="picklist_for_approval" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="picklist_for_approval" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="picklist_for_approval" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="picklist_for_approval" && $field=="vatable")
	{
		return 0;
	}
				if($table=="picklist_for_checking" && $field=="Transadate")
	{
		return now();
	}
				if($table=="picklist_for_checking" && $field=="Terms_Discount_percent")
	{
		return 0;
	}
				if($table=="picklist_for_checking" && $field=="Terms_Discount_days")
	{
		return 0;
	}
				if($table=="picklist_for_checking" && $field=="Terms_due_date")
	{
		return 0;
	}
				if($table=="picklist_for_checking" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="picklist_for_checking" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="picklist_for_checking" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="picklist_for_checking" && $field=="vatable")
	{
		return 0;
	}
				if($table=="picklist_detail_for_approval" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="picklist_detail_for_approval" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="picklist_detail_for_checking" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="picklist_detail_for_checking" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="return_components" && $field=="Transadate")
	{
		return now();
	}
				if($table=="open_production" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="open_production" && $field=="production_status")
	{
		return Done;
	}
				if($table=="fixed_asset_time_usage" && $field=="Transadate")
	{
		return now();
	}
				if($table=="service_visit" && $field=="date")
	{
		return now();
	}
				if($table=="open_cases" && $field=="status")
	{
		return "Open";
	}
				if($table=="open_cases" && $field=="date_of_purchase")
	{
		return Now();
	}
				if($table=="production_stage_detail" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="service_report" && $field=="date_attended")
	{
		return now();
	}
				if($table=="project_name" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="project_name" && $field=="Due_Date")
	{
		return Now();
	}
				if($table=="project_name" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="project_name" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="project_name" && $field=="delivery_status")
	{
		return "Open";
	}
				if($table=="inventory_tranfer_mobile" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="inventory_transfer_detail_mobile" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="item_with_balances" && $field=="Default Cost Price")
	{
		return 0;
	}
				if($table=="item_with_balances" && $field=="Vat Type")
	{
		return "VATable";
	}
				if($table=="item_with_balances" && $field=="Vat Rate")
	{
		return 12;
	}
				if($table=="item_with_balances" && $field=="perpetual_method")
	{
		return 0;
	}
				if($table=="item_with_balances" && $field=="automate_depreciation")
	{
		return 0;
	}
				if($table=="item_with_balances" && $field=="inactive")
	{
		return 0;
	}
				if($table=="item_with_balances" && $field=="purchase_vat_type")
	{
		return "Purchase of Goods";
	}
				if($table=="item_with_balances" && $field=="purchase_vat_rate")
	{
		return 12;
	}
				if($table=="salesapp" && $field=="date")
	{
		return Now();
	}
				if($table=="asset_accountability" && $field=="Transadate")
	{
		return now();
	}
				if($table=="asset_accountability" && $field=="date_asset_must_return")
	{
		return now();
	}
				if($table=="cash_pullout" && $field=="Transadate")
	{
		return now();
	}
				if($table=="cash_pullout_detail" && $field=="transadate")
	{
		return now();
	}
				if($table=="liquidation" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="liquidation" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="liquidation_detail" && $field=="VAT_Type")
	{
		return "Not Qualified for Input";
	}
				if($table=="loan" && $field=="date")
	{
		return now();
	}
				if($table=="loan" && $field=="start_date")
	{
		return now();
	}
				if($table=="loan" && $field=="end_date")
	{
		return now();
	}
				if($table=="marketing_job_order" && $field=="Transadate")
	{
		return now();
	}
				if($table=="marketing_job_order" && $field=="requested_date")
	{
		return now();
	}
				if($table=="spoilage" && $field=="Transadate")
	{
		return now();
	}
				if($table=="tara_sheet" && $field=="Transadate")
	{
		return now();
	}
				if($table=="transmittal_slip" && $field=="date_created")
	{
		return now();
	}
				if($table=="transmittal_slip" && $field=="received_from_date")
	{
		return now();
	}
				if($table=="transmittal_slip" && $field=="received_by_date")
	{
		return now();
	}
				if($table=="transmittal_slip" && $field=="forwarded_to_date")
	{
		return now();
	}
				if($table=="transmittal_slip_detail" && $field=="date")
	{
		return now();
	}
				if($table=="canvass" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="canvass" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="canvass" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="canvass_for_checking" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="canvass_for_checking" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="canvass_for_checking" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="canvass_for_approval" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="canvass_for_approval" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="canvass_for_approval" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="canvass_to_purchase_order" && $field=="VAT_Rate")
	{
		return 0;
	}
				if($table=="canvass_to_purchase_order" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="canvass_to_purchase_order" && $field=="order")
	{
		return $_SESSION["Nextnumber"];
	}
				if($table=="open_cv_for_por" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="open_cv_for_por" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="open_cv_for_por" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="open_cv_for_por" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="open_cv_for_por" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="open_cv_for_por" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="open_cv_for_por" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="open_cv_for_por" && $field=="payable_discount")
	{
		return 0;
	}
				if($table=="open_cv_for_por" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="open_cv_for_por" && $field=="importation")
	{
		return 0;
	}
				if($table=="open_cv_for_por" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="open_cv_for_por" && $field=="payment_method")
	{
		return 1;
	}
				if($table=="open_cv_for_por" && $field=="Transaction_Date")
	{
		return Now();
	}
				if($table=="open_cv_for_liq" && $field=="Transadate")
	{
		return Now();
	}
				if($table=="open_cv_for_liq" && $field=="Gross_Sale")
	{
		return 0;
	}
				if($table=="open_cv_for_liq" && $field=="Discount_Amount")
	{
		return 0;
	}
				if($table=="open_cv_for_liq" && $field=="Vat_Amount")
	{
		return 0;
	}
				if($table=="open_cv_for_liq" && $field=="Taxable")
	{
		return 1;
	}
				if($table=="open_cv_for_liq" && $field=="cash_collection")
	{
		return 0;
	}
				if($table=="open_cv_for_liq" && $field=="Net_pay")
	{
		return 0;
	}
				if($table=="open_cv_for_liq" && $field=="payable_discount")
	{
		return 0;
	}
				if($table=="open_cv_for_liq" && $field=="date_of_importation")
	{
		return Now();
	}
				if($table=="open_cv_for_liq" && $field=="importation")
	{
		return 0;
	}
				if($table=="open_cv_for_liq" && $field=="exchange_rate")
	{
		return 1;
	}
				if($table=="open_cv_for_liq" && $field=="payment_method")
	{
		return 1;
	}
				if($table=="open_cv_for_liq" && $field=="Transaction_Date")
	{
		return Now();
	}
	return "";
}

/**
 * @intellisense
 */
function GetAutoUpdateValue($field, $ptype, $table="")
{
	global $strTableName;
	if(!$table)
		$table=$strTableName;
	return "";
}

/**
 * @intellisense
 */
function GetUploadFolderExpression($field, $file, $table )
{
	return "";
}

/**
 * @intellisense
 */
function mdeleteIndex($i)
{
	return $i-1;
}

/**
 * Call function stack info parser
 * Return array of function calls

 * @intellisense
 * @return array
 */
function parse_backtrace($errfFile, $errLine, $splitAsArray = true)
{
    // get backtrace array
    $backtrace = debug_backtrace();

    // delete calls to error handler functions
	foreach ($backtrace as $i => $call)
    {
    	// cut error handlers calls etc.
    	if ($call['function'] == 'parse_backtrace' ||  $call['function'] == 'error_handler' || $call['function'] == 'trigger_error'){
    		array_shift($backtrace);
    		continue;
    	}
    }
    // if no data return empty array
    if (count($backtrace) == 0) {
        return array();
    }


    $backTraceLen = count($backtrace);
    $backtrace[$backTraceLen]['file'] = $backtrace[$backTraceLen-1]['file'];
    $backtrace[$backTraceLen]['line'] = $backtrace[$backTraceLen-1]['line'];
    $backtrace[$backTraceLen]['function'] =  'Global scope';


 	// make shift of file: line, for better view. It will show not line where function were called, but line where in function error was happend
    for($i=0;$i<count($backtrace);$i++)
    {
    	$errorLineBefore = $backtrace[$i]['line'];
    	$errorFileBefore = $backtrace[$i]['file'];
    	$backtrace[$i]['file'] = $errfFile;
    	$backtrace[$i]['line'] = $errLine;
    	$errLine = $errorLineBefore;
    	$errfFile = $errorFileBefore;
    }

    // result array with data
    $funCallsArray = array();
    // parse array
    foreach ($backtrace as $i => $call)
    {
    	// proccess the data that may not exist
    	if (isset($call['file']))
    	{
    		// get path to the root
			$pathToRoot = substr(dirname(__FILE__),0,strlen(dirname(__FILE__))-strlen("include"));
			// replace it
			$call['file'] = str_replace($pathToRoot, '', $call['file']);
    	}
    	else
    	{
    		$call['file'] = '(null)';

    	}
    	//$call['file'] = !isset($call['file']) ? '(null)' : $call['file'];
    	$call['line'] = !isset($call['line']) ? '0' : $call['line'];
		// proccess file and error line
        $location = $call['file'] . ':' . $call['line'];
        // if object method was called
        if (isset($call['class']))
        {
        	$function = $call['class'].(isset($call['type']) ? $call['type'] : '.').$call['function'];

        }// if function
        else
        {
        	$function = $call['function'];
		}

		$paramMaxDisplay = 2000;
		// proccess arguments
        $params = '';
        if (isset($call['args']))
        {
            $args = array();
            $j=0;
            foreach ($call['args'] as $arg)
            {
            	$j++;
            	// proccess array
                if (is_array($arg))
                {
                	$arrStr = runner_print_r($arg, true);
                    
					$arrStr = strlen($arrStr) < $paramMaxDisplay 
						?  $arrStr 
						: substr($arrStr, 0, $paramMaxDisplay).'...';

                    $args[] = $j.'.&nbsp;'.runner_htmlspecialchars($arrStr).';';
                }
                // process objects
                elseif ( is_object($arg) )
                {
                    $args[] = $j.'.&nbsp;'. runner_htmlspecialchars( get_class( $arg ) ) . ';';
                }
                // another arguments
                else
                {
                	$arg = @strlen($arg) < $paramMaxDisplay 
						?  $arg 
						: substr($arg, 0, $paramMaxDisplay).'...';
                    $args[] = $j.'.&nbsp;'. runner_htmlspecialchars( $arg ).';';
                }
            }
            $params = implode('<br/> ', $args);
        }
		// add in finish array all params
		if (!$splitAsArray)
		{
			$funCallsArray[] = '#'.$i.'&nbsp;&nbsp;'.$function.'('.$params.')&nbsp;&nbsp;called&nbsp;at&nbsp;['.$location.']';
		}
		else
		{
			$funCallsArray[] = array('num' => '#'.$i.'.&nbsp;', 'path' => $location, 'func'=>$function, 'args'=>(strlen($params) ? $params : 'N/A'));
		}
    }

    // return array with call functions strings
    return $funCallsArray;
}

/**
 * display error message
 * @intellisense
 */
function runner_error_handler($errno, $errstr, $errfile, $errline)
{
	global $strLastSQL;
	global $globalSettings;

	if ($errno==2048 || $errno == 8 || $errno == 2 || $errno == 8192)
		return 0;

	if(strpos($errstr,"It is not safe to rely on the system's timezone settings."))
		return 0;
	if(strpos($errstr,"fopen(")===0)
		return 0;

	if ( !$globalSettings["showDetailedError"] )
	{
		echo $globalSettings["customErrorMessage"];
		exit(0);
	}

	$errinfo = array();
	$errinfo['errno'] = $errno;
	$errinfo['errstr'] = runner_htmlspecialchars( $errstr );

	$url = $_SERVER["SERVER_NAME"].$_SERVER["SCRIPT_NAME"];
	if(array_key_exists("QUERY_STRING",$_SERVER))
	{
		$url .= "?".runner_htmlspecialchars($_SERVER["QUERY_STRING"]);
	}

	$errinfo['url'] = $url;
	$errinfo['errfile'] = $errfile;
	$errinfo['errline'] = $errline;

	$sqlStr = isset($strLastSQL) ? runner_htmlspecialchars(substr($strLastSQL,0,20480)) : '';
	$errinfo['sqlStr'] = $sqlStr;

	$errinfo['debugRows'] = parse_backtrace($errfile, $errline);

	runner_show_error($errinfo);
}

/**
 * @intellisense
 */
function no_output_done()
{
	if(headers_sent())
		return false;
	if(ob_get_length())
		return false;
	return true;
}

/**
 * @intellisense
 */
function format_currency($val)
{
	return str_format_currency($val);
}

/**
 * @intellisense
 */
function format_number($val,$valDigits = false)
{
	return str_format_number($val,$valDigits);
}

function formatNumberForHTML5($value)
{
	return $value;
}

/**
 * @intellisense
 */
function format_datetime($time)
{
	return str_format_datetime($time);
}

/**
 * @intellisense
 */
function format_time($time)
{
	return str_format_time($time);
}

/**
 * @intellisense
 */
function secondsPassedFrom($datetime)
{
	$arrDateTime=db2time($datetime);
	return time()-mktime($arrDateTime[3],$arrDateTime[4],$arrDateTime[5],$arrDateTime[1],$arrDateTime[2],$arrDateTime[0]);
}

/**
 * @intellisense
 */
function xtempl_call_func($func,&$params)
{
	if(function_exists($func))
	{
		$func($params);
	}
}

/**
 * @intellisense
 */
function echoBinary($string, $bufferSize = 8192)
{
	for ($chars=strlen($string)-1,$start=0;$start <= $chars;$start += $bufferSize)
		echo substr($string,$start,$bufferSize);
}

/**
 * @intellisense
 */
function echoBinaryPartial($string, $startPos, $endPos, $bufferSize = 8192)
{
	$length = $endPos - $startPos + 1;
	if($length < $bufferSize)
		$bufferSize = $length;
	for ($start = $startPos; $start <= $endPos && $bufferSize > 0;)
	{
		echo substr($string, $start, $bufferSize);
		$start += $bufferSize;
		if($start + $bufferSize > $length)
			$bufferSize = $length - $start;
	}
}

/**
 * @intellisense
 */
function setObjectProperty(&$obj,$key,&$value)
{
	$obj->$key = &$value;
}

/**
 * @intellisense
 */
function returnError404()
{
	header("HTTP/1.0 404 Not Found");
}

/**
 * @intellisense
 */
function execute_events(&$params)
{
	if(function_exists(@$params["custom1"]))
		eval($params["custom1"].'($params);');
}

/**
 * @intellisense
 */
function GetMySQLLastInsertID( $connection )
{
//	select LAST_INSERT_ID() for ASP
	return $connection->getInsertedId();
}

/**
 * @intellisense
 */
function DoInsertRecord($table, &$avalues, &$blobfields, &$pageObject)
{
	return DoInsertRecordSQL($table, $avalues, $blobfields, $pageObject);
}


/**
 * @intellisense
 */
function xtempl_include_header($xt,$fname,$param)
{
	$xt->assign_function($fname,"xt_include",array("file"=>$param));
}

function xt_include($params)
{
	if(file_exists(getabspath($params["file"])))
		include(getabspath($params["file"]));
}

/**
 * @intellisense
 */
function binPrint(&$value, $size)
{
	echobig($value,$size);
}

/**
 * construct "good" field name
 * @intellisense
 */
function GoodFieldName($field)
{
	global $cCharset;
	if ($cCharset == "utf-8"){
		$field = utf8_decode($field);
	}
	$field=(string)$field;
	$out="";
	for($i=0;$i<strlen($field);$i++)
	{
		$t=substr($field,$i,1);
		if((ord($t)<ord('a') || ord($t)>ord('z')) && (ord($t)<ord('A') || ord($t)>ord('Z')) && (ord($t)<ord('0') || ord($t)>ord('9')))
			$out.='_';
		else
			$out.=$t;
	}
	return $out;
}

/**
 * @intellisense
 */
function xt_getvar(&$xt,$name)
{
	global $testingLinks;
	for($i = count($xt->xt_stack)-1;$i>=0;$i--)
	{
		if(isset($xt->xt_stack[$i][$name]))
			return $xt->xt_stack[$i][$name];
	}
	if(!$xt->testingFlag)
		return false;

	if(isset($testingLinks[$name]))
		return "func=\"".$testingLinks[$name]."\"";
	else
		return false;
}


/**
 * @intellisense
 */
/*
function xt_process_template(&$xt,$str)
{
//	parse template file tag by tag
	$varparams=array();
	$start=0;
	$literal=false;
	$len = strlen($str);
	while(true)
	{
		$pos = strpos($str,"{",$start);
		if($pos===false)
		{
			echo substr($str,$start,$len-$start);
			break;
		}
		$section=false;
		$var=false;
		$message=false;
		if(substr($str,$pos+1,6)=="BEGIN ")
			$section=true;
		elseif(substr($str,$pos+1,1)=='$')
			$var=true;
		elseif(substr($str,$pos+1,14)=='mlang_message ')
		{
			$message=true;
		}
		else
		{
//	no tag, just '{' char
			echo substr($str,$start,$pos-$start+1);
			$start=$pos+1;
			continue;
		}
		echo substr($str,$start,$pos-$start);
		if($section)
		{
//	section
			$endpos=strpos($str,"}",$pos);
			if($endpos===false)
			{
				$xt->report_error("Page is broken");
				return;
			}
			$section_name=trim(substr($str,$pos+7,$endpos-$pos-7));
			$endtag="{END ".$section_name."}";
			$endpos1=strpos($str,$endtag,$endpos);
			if($endpos1===false)
			{
				echo "End tag not found:".runner_htmlspecialchars($endtag);
				$xt->report_error("Page is broken");
				return;
			}
			$section=substr($str,$endpos+1,$endpos1-$endpos-1);
			$start=$endpos1+strlen($endtag);
			$sectionVar = xt_getvar($xt,$section_name);
			if($sectionVar===false)
			{
				continue;
			}
			$begin="";
			$end="";
			if(is_array($sectionVar))
			{
				$begin=@$sectionVar["begin"];
				$end=@$sectionVar["end"];

				$var=@$sectionVar["data"];
			}
			else
			{
				$var = $sectionVar;
			}
			if(!is_array($var))
			{
//	if section
				echo $begin;
				if(is_array($sectionVar))
					$xt->xt_stack[]=&$sectionVar;
				xt_process_template($xt,$section);
				if(is_array($sectionVar))
					array_pop($xt->xt_stack);
				$xt->processVar($end, $varparams);
			}
			else
			{
//	foreach section
				echo $begin;
				$keys=array_keys($var);
				foreach($keys as $i)
				{
					$xt->xt_stack[]=&$var[$i];
					if(is_array($var[$i]) && isset($var[$i]["begin"]))
						echo $var[$i]["begin"];
					xt_process_template($xt,$section);
					array_pop($xt->xt_stack);
					if(is_array($var[$i]) && isset($var[$i]["end"]))
						echo $var[$i]["end"];
				}
				$xt->processVar($end, $varparams);
			}
		}
		elseif($var)
		{
//	display a variable or call a function
			$endpos=strpos($str,"}",$pos);
			if($endpos===false)
			{
				$xt->report_error("Page is broken");
				return;
			}
			$varparams=array();
			$var_name = trim(substr($str,$pos+2,$endpos-$pos-2));
			if(strpos($var_name," ")!==FALSE)
			{
				$varparams = explode(" ",$var_name);
				$var_name = $varparams[0];
				unset($varparams[0]);
			}
			$start=$endpos+1;
			$var = xt_getvar($xt,$var_name);
			if($var===false)
			{
				continue;
			}
			$xt->processVar($var, $varparams);
		}
		elseif($message)
		{
			$endpos=strpos($str,"}",$pos);
			if($endpos===false)
			{
				$xt->report_error("Page is broken");
				return;
			}
			$tag = trim(substr($str,$pos+15,$endpos-$pos-15));
			$start=$endpos+1;
			echo runner_htmlspecialchars(mlang_message($tag));
		}
	}
}
*/

/**
 * @intellisense
 */
function parse_addr_list($to)
{
	$addr_arr = array();

	$to = preg_replace('/^[\s*,]+|[\s*,]+$/',"", $to);
	$to = preg_replace('/\s+,/',",", $to);
	//split $to by ',' not surrounded by quotes or round brackets
	$arr = preg_split('/(,(?=([^"]*("[^"]*")?)*$))(?![^\(]*(\),|\)$))/', $to);

  	$matches = array();
    foreach($arr as $item)
	{
		$item = trim($item);
		if($item != "")
		{
			//match an email not surrounded by quotes or round brackets
			preg_match_all('/(([A-Za-z\d_\-\.+]+@[A-Za-z\d_\-\.]+\.[A-Za-z\d_\-]+)(?=([^"]*("[^"]*")?)*$))(?![^\(]*(\),|\)$))/', $item, $matches);
			if(count($matches[0]) == 1)
			{
			    $name = preg_replace('/(([A-Za-z\d_\-\.+]+@[A-Za-z\d_\-\.]+\.[A-Za-z\d_\-]+)(?=([^"]*("[^"]*")?)*$))(?![^\(]*(\),|\)$))/',"", $item);
			    $name = preg_replace('/"|<>$/',"", $name);
				$addr_arr[] = array('addr' => $matches[0][0], 'name' => $name);
			}
		}
	}

	return $addr_arr;
}

/**
 * @param Array params
 * @return Array
 * @intellisense
 */
function runner_mail_smtp( $params )
{
	$mail = new PHPMailer( true );
	$mail->IsSMTP(); // telling the class to use SMTP

	$useCustomSMTP = GetGlobalData("useCustomSMTPSettings", false);
	$SMTPUser = GetGlobalData("strSMTPUser", "");

	if( $useCustomSMTP && $SMTPUser != "" || isset( $params['username'] ) )
	{
		$mail->SMTPAuth = true;  // enable SMTP authentication
		$mail->Username = isset( $params['username'] ) ? $params['username'] : $SMTPUser;  // SMTP username
		$mail->Password = isset( $params['password'] ) ? $params['password'] : GetGlobalData("strSMTPPassword", "");  // SMTP password
	}
	else
	{
		$mail->SMTPAuth = false;
	}

	$SMTPServer = GetGlobalData("strSMTPServer", "");
	if( $useCustomSMTP && $SMTPServer != "" || isset( $params['host'] ) )
	{
		$mail->Host = isset( $params['host'] ) ? $params['host'] : $SMTPServer;  // sets SMTP server
	}
	else if( ini_get('SMTP') != '' )
	{
		$mail->Host = ini_get('SMTP');
	}

	if( $mail->Host == "" ) {
		return array(
			"mailed" => false,
			"success" => false,
			"message" => "Email server connection is not specified. Setup the connection on the Miscellaneous - Email settings... dialog."
		);

	}


	$SMTPPort = GetGlobalData("strSMTPPort", "");
	if( $useCustomSMTP && $SMTPPort != "" || isset( $params['port'] ) )
	{
		$mail->Port = isset( $params['port'] ) ? $params['port'] + 0 : $SMTPPort + 0;  // set the SMTP port
	}
	else if( ini_get('smtp_port') != '' )
	{
		 $mail->Port = ini_get('smtp_port') + 0;
	}

	$mail->SMTPSecure = GetGlobalData("SMTPSecure", "");

	$mail->Subject = $params['subject'];

	$from = isset( $params['from'] ) ? $params['from'] : "";
	if( !$from )
		$from = GetGlobalData("strFromEmail", "");

	try
	{
		$mail->SetFrom( $from, isset( $params['fromName'] ) ? $params['fromName'] : "" );
	}
	catch( phpmailerException $e )
	{
		return array( "mailed" => false, "message"=>  $e->getMessage()  );
	}

	$to = isset( $params['to'] ) ? $params['to'] : "";
	if( $to != "" )
	{
		$arr_to = parse_addr_list( $to );
		foreach( $arr_to as $email )
		{
			$mail->AddAddress( $email['addr'], $email['name'] );
		}
	}

	// replyTo
	if ( isset( $params['replyTo'] ) )
		$mail->AddReplyTo( $params['replyTo'], "" );

	$body = isset( $params['body'] ) ? $params['body'] : "";

	// body, htmlbody
	if ( isset( $params['htmlbody'] ) )
	{
		$mail->AltBody = $body;
		$mail->MsgHTML( $params['htmlbody'] );
	}
	else
	{
		$mail->Body = $body;
	}

	// charset
	if ( isset( $params['charset'] ) )
		$mail->CharSet = $params['charset'];
	else
		$mail->CharSet = "utf-8";

	// priority
	if( isset( $params['priority'] ) )
		$mail->Priority = $params['priority'];

	// CC
	if( isset( $params['cc'] ) )
	{
		$arr_cc = parse_addr_list( $params['cc'] );
		foreach( $arr_cc as $cc )
		{
			$mail->AddCC( $cc['addr'], $cc['name'] );
		}
	}

	// BCC
	if( isset( $params['bcc'] ) )
	{
		$arr_bcc = parse_addr_list( $params['bcc'] );
		foreach( $arr_bcc as $bcc )
		{
			$mail->AddBCC( $bcc['addr'], $bcc['name'] );
		}
	}

	if( isset( $params['attachments'] ) && is_array( $params['attachments'] ) )
	{
		foreach ( $params['attachments'] as $attachment )
		{
			$mail->AddAttachment( $attachment['path'],
				isset( $attachment['name'] ) ? $attachment['name'] : '',
				isset( $attachment["encoding"] ) ? $attachment["encoding"] : 'base64',
				isset( $attachment["type"] ) ? $attachment["type"] : 'application/octet-stream' );
		}
	}

	try
	{
		$res = $mail->Send();
	}
	catch( phpmailerException $e )
	{
		return array( "success" => false, "mailed" => false, "message"=> $e->getMessage() );
	}

	return array( "success" => $res, "mailed" => $res, "message"=> $mail->ErrorInfo );
}

/**
 * @intellisense
 */
function getFileNameFromURL()
{
	$scriptname = $_SERVER["PHP_SELF"];
	$pos = strrpos($scriptname, "/");
	if($pos !== FALSE)
		$scriptname = substr($scriptname, $pos + 1);
	return $scriptname;
}

/**
 * @intellisense
 */
function strlen_bin(&$str)
{
	return strlen($str);
}

/**
 * The code of ODBCFunctions::stripSlashesBinary was
 * refactored as db_stripslashesbinaryAccess function
 * to convert in ASP correctly
 * @param String str
 * @return String
 * @intellisense
 */
function db_stripslashesbinaryAccess($str)
{
	if( is_array($str) )
		$str = implode('', $str);

	//	try to remove ole header for BMP pictures
	$pos = strpos($str, ".Picture");
	if( $pos === false || $pos > 300 )
		return $str;

	$pos1 = strpos($str, "BM", $pos);
	if( $pos1 === false || $pos1 > 300 )
		return $str;

	return substr($str, $pos1);
}

/**
 * @intellisense
 */
function SendContentLength($len)
{
	header("Content-Length: ".$len);
}

/**
 * @intellisense
 */
function DecodeUTF8($str)
{
	return $str;
}
/**
 * @intellisense
 */
function escapeEntities($str)
{
	return $str;
}

/**
 * @intellisense
 */
function empty_error_handler()
{
	return true;
}

/**
 * @intellisense
 */
function n_printDebug()
{
}

/**
 * @param Array arr
 */
function getArrayWithoutObjects( $arr, &$print_r_depth )
{
	$copyArr = $arr;
	++$print_r_depth;
	foreach( $arr as $idx => $val )
	{
		$type = gettype( $val );

		if( $type == "object" )
			$copyArr[ $idx ] = get_class( $val )." Object";

		if( $type == "array" )
		{
			if( $print_r_depth < 5 )
				$copyArr[ $idx ] = getArrayWithoutObjects( $val, $print_r_depth );
			else
				$copyArr[ $idx ] = "Array";
		}
	}
	--$print_r_depth;
	return $copyArr;
}

/**
 * @param Mixed value
 * @param Boolean return
 * @param Number n
 */
function runner_print_r( $value, $return = false )
{
	$print_r_depth = 0;
	$valueCopy = $value;
	$type = gettype( $value );

	if( $type == "object" )
		$valueCopy = get_class( $valueCopy )." Object";

	if( $type == "array" )
		$valueCopy = getArrayWithoutObjects( $valueCopy, $print_r_depth );

	return print_r( $valueCopy, $return );
}

/**
 * @intellisense
 */
function in_arrayi($needle, $haystack)
{
	$found = false;
    foreach( $haystack as $value )
	{
        if( strtolower( $value ) == strtolower( $needle ) )
            $found = true;
    }
    return $found;
}

/**
 * @intellisense
 */
function f_printDebug()
{

	$f = fopen("_dataLog.txt", "a");
	$trace = debug_backtrace();
	fwrite($f, var_export($trace[0]['args'], true));
	fclose($f);

}

if(!function_exists("hex2bin"))
{
/**
 * Convert HEX string to BIN string
 * @param {string} HEX source string
 * @return {string} BIN string
 * @intellisense
 */
function hex2bin($source)
	 {
		if(!is_string($source) || strlen($source) == 0 || strlen($source) % 2 > 0)
			return '';
		$bin = "";
		$i = 0;
		do {
			$bin .= chr(hexdec($source[$i].$source[$i + 1]));
			$i += 2;
		} while ($i < strlen($source));
		return $bin;
	}
}

/**
 * @intellisense
 */
function toPHPTime($datevalue)
{
	$arr = db2time($datevalue);
	return mktime($arr[3],$arr[4],$arr[5],$arr[1],$arr[2],$arr[0]);
}

/**
 *
 * @param resource $image
 * @param string $file_path JPG/JPEG file, function reads* EXIF header
 * @return resource|null 
 */
function exifRotateImage($image, $file_path) {
	/*
	define('ROTATE_0', 1);
	define('ROTATE_0_MIRROR', 2);
	define('ROTATE_180', 3);
	define('ROTATE_180_MIRROR', 4);
	define('ROTATE_90', 5);
	define('ROTATE_90_MIRROR', 6);
	define('ROTATE_270', 7);
	define('ROTATE_270_MIRROR', 8);
	*/

	$exif = exif_read_data($file_path);

	if (!$exif) {
		return false;
	}

	$orientation = $exif['Orientation'];

	$rotated = null;
	$success = true;
	//definition of values commented at the start of this function
	switch ($orientation) {
		case 0:
		case 1:
			$rotated = imagerotate($image, 0, 0);
			break;
		case 2:
			$success = imageflip($image, IMG_FLIP_HORIZONTAL);
			break;
		case 3:
			$rotated = imagerotate($image, 180, 0);
			break;
		case 4:
			$rotated = imageflip($image, IMG_FLIP_VERTICAL);
			break;
		case 5:
			$rotated = imagerotate($image, -90, 0);
			$success = imageflip($rotated, IMG_FLIP_HORIZONTAL);
			break;
		case 6:
			$rotated = imagerotate($image, -90, 0);
			break;
		case 7:
			$rotated = imagerotate($image, 90, 0);
			$success = imageflip($rotated, IMG_FLIP_HORIZONTAL);
			break;
		case 8:
			$rotated = imagerotate($image, 90, 0); 
			break;
		default:
			return null;
	}

	if (!$success) {
		@imagedestroy($rotated);
		$rotated = null;
	}

	return $rotated;
}

/**
 * @intellisense
 */
function imageCreateThumb($new_width,$new_height,$img_width,$img_height,$file_path,$options,$new_file_path,$uploadedFile)
{
	$new_img = @imagecreatetruecolor($new_width, $new_height);
	switch (strtolower(substr(strrchr($file_path, '.'), 1))) {
		case 'jpg':
		case 'jpeg':
			$src_img = @imagecreatefromjpeg($file_path);
			$image_quality = isset($options['jpeg_quality']) ?
				$options['jpeg_quality'] : 75;
			$success = @imagecopyresampled(
					$new_img,
					$src_img,
					0, 0, 0, 0,
					$new_width,
					$new_height,
					$img_width,
					$img_height
			);

			if (!$success)
				break;
			
			if (function_exists("exif_read_data")) {
				$rotated_img = exifRotateImage($new_img, $file_path);
			}

			if ($rotated_img) {
				@imagedestroy($new_img);
				$new_img = $rotated_img;
			}
			
			$success = @imagejpeg($new_img, $new_file_path, $image_quality);


			break;
		case 'gif':
			@imagecolortransparent($new_img, @imagecolorallocate($new_img, 0, 0, 0));
			$src_img = @imagecreatefromgif($file_path);
			$image_quality = null;
			$success = @imagecopyresampled(
					$new_img,
					$src_img,
					0, 0, 0, 0,
					$new_width,
					$new_height,
					$img_width,
					$img_height
				) && imagegif($new_img, $new_file_path, $image_quality);
			break;
		case 'png':
			@imagecolortransparent($new_img, @imagecolorallocate($new_img, 0, 0, 0));
			@imagealphablending($new_img, false);
			@imagesavealpha($new_img, true);
			$src_img = @imagecreatefrompng($file_path);
			$image_quality = isset($options['png_quality']) ?
				$options['png_quality'] : 9;
			$success = @imagecopyresampled(
					$new_img,
					$src_img,
					0, 0, 0, 0,
					$new_width,
					$new_height,
					$img_width,
					$img_height
				) && imagepng($new_img, $new_file_path, $image_quality);
			break;
		default:
			$src_img = null;
			$success = false;
	}
	// Free up memory (imagedestroy does not delete files):
	@imagedestroy($src_img);
	@imagedestroy($new_img);
	return $success;
}
/**
 * @intellisense
 */
function uploadFiles($option)
{
	$result = null;
	if(isset($_FILES[$option])){
		$result = array();
		$upload = $_FILES[$option];
		if(is_array($upload['tmp_name'])) {
            foreach ($upload['tmp_name'] as $index => $value)
            {
            	$tempFile = array();
				$tempFile['tmp_name'] = $upload['tmp_name'][$index];
                $tempFile['name'] = $upload['name'][$index];
                $tempFile['size'] = $upload['size'][$index];
                $tempFile['type'] = $upload['type'][$index];
                $tempFile['error'] = $upload['error'][$index];
                $result[] = $tempFile;
            }
		}
		else
		{
			$result[] = $upload;
		}
	}
	return $result;
}
/**
 * @intellisense
 */
function upcount_name_callback($matches)
{
	$index = isset($matches[1]) ? intval($matches[1]) + 1 : 1;
	$ext = isset($matches[2]) ? $matches[2] : '';
	return ' ('.$index.')'.$ext;
}

/**
 * @intellisense
 */
function upcount_name($name)
{
	return preg_replace_callback(
		'/(?:(?: \(([\d]+)\))?(\.[^.]+))?$/',
		'upcount_name_callback',
		$name,
		1
	);
}

/**
 * @intellisense
 */
function trim_file_name($name, $type, $index, $obj)
{
        // Remove path information and dots around the filename, to prevent uploading
        // into different directories or replacing hidden system files.
        // Also remove control characters and spaces (\x00..\x20) around the filename:
        $file_name = trim(basename($name,""));
        // Add missing file extension for known image types:
        if (strpos($file_name, '.') === false &&
            preg_match('/^image\/(gif|jpe?g|png)/', $type, $matches)) {
            $file_name .= '.'.$matches[1];
        }
        while(isset($_SESSION["mupload_".$obj->formStamp][$file_name])) {
            $file_name = upcount_name($file_name);
        }
        return $file_name;
    }

/**
 * @intellisense
 */
function upload_File($uploadedFile, $destination)
{
	if ($uploadedFile && is_uploaded_file($uploadedFile["tmp_name"]))
	{
		move_uploaded_file($uploadedFile["tmp_name"], $destination);
		clearstatcache();
		clearstatcache();
	}
}

/**
 * GDExist
 * Fake function. Only matter something for ASP, because in PHP GD always exist (since 4.3.0)
 * @intellisense
 */
function GDExist()
{
	return true;
}

/**
 * @intellisense
 */
function makeSurePathExists($abspath)
{
	if(!file_exists($abspath))
	{
		return mkdir($abspath, 0777,  true);
	}
	if(is_dir($abspath))
		return true;
	return false;
}

/**
 * @intellisense
 */
function createControlClass($className, $field, $pageObject, $id, $connection)
{
	include_once(getabspath("classes/controls/".$className.".php"));
	return new $className($field, $pageObject, $id, $connection);
}

/**
 * @intellisense
 */
function createViewControlClass($className, $field, $container, $pageObject)
{
	include_once(getabspath("classes/controls/".$className.".php"));
	return new $className($field, $container, $pageObject);
}

/**
 * @intellisense
 */
function getQueryString()
{
	return getenv('QUERY_STRING') ? urldecode(getenv('QUERY_STRING')) : $_SERVER["QUERY_STRING"];
}

/**
 * GetTableLink
 * Form proper link for table. Really need for ASP.Net MVC
 * @param {string} Table name
 * @param {string} Page type
 * @param (string) GET query string
 */
function GetTableLink($table, $pageType = "", $getParams = "")
{
	$url = $table;
	if($pageType != "")
	{
		$url .= "_".$pageType;
	}
	$url .= ".php";
	if($getParams != "")
	{
		$url .= "?".$getParams;
	}

	return $url;
}

/**
 * GetLocalLink
 * Only needed in .NET
 *
 * @param {string} Table name
 * @param {string} Page type
 * @param (string) GET query string
 */
function GetLocalLink($table, $pageType = "", $getParams = "")
{
	//	used in ASP.NET only
	return GetTableLink( $table, $pageType, $getParams );
}


function GetTemplateName($table, $templateName)
{
	if( $templateName == "" )
		return ".global_" . $table . ".htm";

	if( $table == "" ) {
		return $templateName . ".htm";
	}
	return $table."_".$templateName . ".htm";
}

function HeaderRedirect($table, $pageType = "", $getParams = "")
{
	header("Location: ".GetTableLink($table, $pageType, $getParams));
}

function cross_sort_arr_y($a,$b)
{
	global $group_sort_y;
	if($group_sort_y[$a]>$group_sort_y[$b])
		return true;
	else
		return false;
}

function SortForCrossTable(&$sort_y)
{
	usort($sort_y, "cross_sort_arr_y");
}

function getYMDdate($unixTimeStamp)
{
	return date("Y-m-d", $unixTimeStamp);
}

function getHISdate($unixTimeStamp)
{
	return date("H:i:s", $unixTimeStamp);
}

function IsJSONAccepted()
{
	return isset($_SERVER['HTTP_ACCEPT']) && (strpos($_SERVER['HTTP_ACCEPT'], 'application/json') !== false);
}

function GetRootPathForResources($filePath)
{
	return $filePath;
}

function GetPageURLWithGetParams()
{
	$pagename = $_SERVER["REQUEST_URI"];
	if(!$pagename)
	{
		$pagename=basename(__file__);
		$params="";
		foreach($_GET as $k=>$v)
		{
			if(strlen($params))
				$params.="&";
			$params.=rawurlencode($k)."=".rawurlencode($v);
		}
		if(strlen($params))
			$pagename.="?".$params;
	}
	if(strpos($pagename,"?")===false)
	{
		$pagename.="?pdf=1";
	}
	else
	{
		$pagename.="&pdf=1";
	}

	return $pagename;
}

/*
 * Dummy for ASP.Net MVC
 */
function GetWebRootPath()
{
	return "";
}

function GetCaptchaPath()
{
	return "securitycode.php";
}

function GetCaptchaSwfPath()
{
	return "securitycode.swf";
}


/**
 * This function is used for my_json_encode() function.
 * It will emulate the JSON_UNESCAPED_UNICODE option for json_encode() function.
 */
function json_mb_encode_numericentity(&$item, $key)
{
	if (is_string($item))
		$item = runner_encode_numeric_entity($item, array(0x80, 0xffff, 0, 0xffff), 'UTF-8');
}

function makeFloat($value)
{
	$value = str_replace(",",".",$value);
	if(is_numeric($value))
		return (float)$value;
	else
		return "";
}

/**
 * Get the data array containing the flag indicating if
 * the string passed is HTML entity and the length of
 * the HTML entity that is set by the string
 * @param String encodedEntity
 * @return Array
 */
function getHTMLEntityData($encodedEntity)
{
	$entity = html_entity_decode( $encodedEntity );
	if( $encodedEntity == $entity )
		return array("isHTMLEntity"=> false, "entityLength"=> 0);

	return array("isHTMLEntity"=> true, "entityLength"=> runner_strlen( $entity ));
}

/**
 * PHP html entity decode
 */
function runner_html_entity_decode($str)
{
	// '&nbsp;' entity is not ASCII code 32 but ASCII code 160 (0xa0)
	return html_entity_decode(str_replace('&nbsp;', ' ', $str), ENT_COMPAT | ENT_HTML401, 'ISO-8859-1');
}

/**
 * PHP htmlspecialchars wrapper
 */
function runner_htmlspecialchars($str)
{
	global $useUTF8;

	if($useUTF8)
		return htmlspecialchars($str, ENT_HTML5 | ENT_IGNORE | ENT_COMPAT);

	return htmlspecialchars($str, ENT_IGNORE | ENT_COMPAT | ENT_HTML401, 'ISO-8859-1');
}

/**
 * PHP strlen wrapper
 */
function runner_strlen($str)
{
	global $useUTF8, $mbEnabled;

	if( !$useUTF8 )
		return strlen($str);

	if( $mbEnabled )
		return mb_strlen($str, 'UTF-8');

	//php.net not ISO-8859-1 characters are converted to '?' (one char).
	return strlen( utf8_decode($str) );
}

/**
 * PHP strpos wrapper
 */
function runner_strpos($haystack, $needle, $offset = 0)
{
	global $useUTF8, $mbEnabled;

	if( !$useUTF8 )
		return strpos($haystack, $needle);

	if( $mbEnabled )
		return mb_strpos($haystack, $needle,  $offset, 'UTF-8');

	if( $offset < 0 )
		return FALSE;

	if( $offset > 0 )
		$haystack = runner_substr($haystack, $offset, runner_strlen($haystack) - $offset);

	$pos = strpos($haystack, $needle);
	if( $pos === FALSE )
		return $pos;

	return $offset + runner_strlen( substr($haystack, 0, $pos) );
}

/**
 * PHP strrpos wrapper
 */
function runner_strrpos($haystack, $needle, $offset = 0)
{
	global $useUTF8, $mbEnabled;

	if( !$useUTF8 )
		return strrpos($haystack, $needle, $offset);

	if( $mbEnabled )
		return mb_strrpos($haystack, $needle, $offset, 'UTF-8');

	if( $offset < 0 )
		$offset = runner_strlen($haystack) + $offset;

	if( $offset > 0 )
		$haystack = runner_substr($haystack, $offset, runner_strlen($haystack) - $offset);

	$rpos = strrpos($haystack, $needle);
	if( $rpos === FALSE )
		return $rpos;

	return $offset + runner_strlen( substr($haystack, 0, $rpos) );
}

/**
 * PHP substr wrapper
 * @param String string
 * @param Number start (>= 0)
 * @param Number length (>= 0)
 * @return String
 */
function runner_substr($string, $start, $length = -1)
{
	if( $length < 0 ) {
		$length = runner_strlen( $string ) - $start;
	}
	if( !$length )
		return "";

	global $useUTF8, $mbEnabled;

	if( !$useUTF8 )
		return substr($string, $start, $length);

	if( $mbEnabled )
		return mb_substr($string, $start, $length, 'UTF-8');

	$end = $start + $length;
	//j is the real chars counter;
	$u8start = $u8end = $j = 0;
	for($i = 0; $i < strlen($string), $j < $end; $i++)
	{
		if($j == $start)
			$u8start = $i;

		$ordord = ord($string[$i]);
		switch(true)
		{
			case (0xFC == (0xFC & $ordord)):
				$i = $i + 5;
			break;
			case (0xF8 == (0xF8 & $ordord)):
				$i = $i + 4;
			break;
			case (0xF0 == (0xF0 & $ordord)):
				$i = $i + 3;
			break;
			case (0xE0 == (0xE0 & $ordord)):
				$i = $i + 2;
			break;
			case (0xC0 == (0xC0 & $ordord)) :
				$i = $i + 1;
		}
		$j++;
	}
	$u8end = $i;

	return substr($string, $u8start, $u8end - $u8start );
}

/**
 * PHP mb_convert_encoding wrapper
 * @return String	Initial or converted
 */
function runner_convert_encoding( $str, $to_encoding, $from_encoding ) {
	global $mbEnabled;

	if( $mbEnabled ) {
		$ret = mb_convert_encoding( $str, $to_encoding, $from_encoding );
		if( $ret !== false )
			return $ret;
	}
	return $str;
}

/**
 * PHP mb_encode_numericentity wrapper
 */
function runner_encode_numeric_entity($str, $convmap, $encoding)
{
	global $mbEnabled;

	if( $mbEnabled )
		return mb_encode_numericentity($str, $convmap, $encoding);

	return $str;
}

/**
 * PHP mb_decode_numericentity wrapper
 */
function runner_decode_numeric_entity($str, $convmap, $encoding)
{
	global $mbEnabled;

	if( $mbEnabled )
		return mb_decode_numericentity($str, $convmap, $encoding);

	return $str;
}

function hasNonAsciiSymbols($str)
{
	$str = "".$str;
	for($i=0; $i<strlen($str); $i++)
	{
		if(ord($str[$i])>127)
			return true;
	}
	return false;
}

function runner_serialize_array($arr)
{
	return serialize($arr);
}

function runner_unserialize_array($arr)
{
	return unserialize($arr);
}

function runner_getimagesize($file_name, $uploadedFile)
{
	return @getimagesize($file_name);
}

function array_merge_assoc($arr1, $arr2)
{
	return array_merge($arr1, $arr2);
}

function getIntervalLimitsExpressions($table, $field, $idx, $isLowerBound)
{
	return getIntervalLimitsExprs($table, $field, $idx, $isLowerBound);
}

/**
 * @return Boolean
 */
function useMySQLiLib()
{
	global $useOldMysqlLib;

	if( !$useOldMysqlLib )
		return extension_loaded("mysqli") === true;

	return extension_loaded("mysql") !== true;
}

/**
 * @return Boolean
 */
function isSqlsrvExtLoaded()
{
	return extension_loaded("sqlsrv") === true;
}

/**
 * @return Boolean
 */
function useMSSQLWinConnect()
{
	return strtoupper(substr(PHP_OS, 0, 3)) == "WIN" && substr(PHP_VERSION, 0, 1) > '4' && class_exists ('COM');
}


/**
 * @param String line
 * @param String bom? UTF-8 default
 * fix it!
 */
function cutBOM( $line, $bom = "\xEF\xBB\xBF" ) {	
	if( substr( $line, 0, strlen( $bom ) ) == $bom )
		return substr( $line, strlen( $bom ) );
	
	return $line;
}

function printBOM()
{
	echo "\xEF\xBB\xBF";
}

function runner_save_textfile( $fileName, $txtData )
{
	runner_save_file( $fileName, $txtData );
}

function deleteTemporaryFilesFromDirTMP()
{
	return false;
}

function runner_date_format($param, $date="")
{
	if($date == "")
		return date($param);
	else
		return date($param, $date);
}

function runner_set_page_timeout( $seconds )
{
	if( !ini_get("safe_mode") )
		set_time_limit(300);
}

/**
 * password_hash wrapper
 */
function getPasswordHash( $pass )
{
	return password_hash( $pass, PASSWORD_BCRYPT );
}

/**
 * password_hash wrapper
 */
function passwordVerify( $pass, $hash )
{
	return password_verify( $pass, $hash ) ;
}


function callDashboardSnippet( $name, $eventsObject )
{
	$snippetData = array();
	ob_start();
	$header = "";
	$funcName = "event_" . GoodFieldName( $name );
	$eventsObject->$funcName( $header );
	$snippetData["header"] = $header;
	$snippetData["body"] = ob_get_contents();
	ob_end_clean();
	return $snippetData;
}

/**
 *	Wrapper for preg_match_all function with PREG_OFFSET_CAPTURE parameter
 *  Returns array of these elements:
 *  Array (
 *		"match" => <full match string>
 *		"offset" => <offset of the match in the original string>
 *		"submatches" => <array of submatch strings>
 *	)
 *
 */
function findMatches( $pattern, $str )
{
	$matches = array();
	$ret = array();
	preg_match_all( $pattern, $str, $matches, PREG_OFFSET_CAPTURE );
	$submatches = count( $matches ) - 1;
	foreach( $matches[0] as $i => $m )
	{
		$match["match"] = $m[0];
		$match["offset"] = $m[1];
		$match["submatches"] = array();
		for( $j = 0; $j < $submatches; ++$j )
		{
			$match["submatches"][] = $matches[ $j+1 ][ $i ][ 0 ];
		}
		$ret[] = $match;
	}

	return $ret;
}

function getPageStrings( $tableName ) {
	require_once( getabspath("include/".$tableName."_pages.php"  ));
	return $pageStrings;
}

function importTableSettings( $table )
{
	global $tables_data, $field_labels, $fieldToolTips, $placeHolders, $page_titles, $detailsTablesData, $masterTablesData, $tableEvents, $bSubqueriesSupported;
	include_once(getabspath("include/".GetTableURL($table)."_settings.php"));
}

function importPageOptions( $table, $page )
{
	if( !$page )
		return;
	global $pd_pages, $page_options;
	if( !isset( $page_options[ $table ] ) ) {
		$page_options[ $table ] = array();
		$pd_pages[ $table ] = array();
	}
	if( isset( $page_options[ $table ][ $page ] ) )
		return;
	include_once(getabspath("include/pages/".GetTableURL($table)."_".$page.".php"));
	$page_options[ $table ][ $page ] = $optionsArray;
	$pd_pages[ $table ][ $page ] = $pageArray;
}

function loadMaps( $pSet ) {
	global $globalEvents;
	foreach($pSet->maps() as $m ) {
		$funcname = "event_" . GoodFieldName( $m );
		$param = array();
		$globalEvents->$funcname( $param );
	}

}

function importTableInfo( $varname ) {
	global $dal_info;
	include_once( getabspath( "include/dal/" . $varname . ".php" ) );
}

function cloneArray( $arr ) {
	//	workaround for some bug in PHP 5.5
	$newArr = array();
	foreach( array_keys( $arr ) as $k )
	{
		$newArr[$k] = $arr[$k];
	}
	return $newArr;
}


function simplify_file_name( $file_name )
{
	$newNameArr = array();

	for( $i = 0; $i < strlen( $file_name ); ++$i ) {
		$c = substr( $file_name, $i, 1 );
		if( ord( $c ) < 128 )
			$newNameArr[] = $c;
		else
			$newNameArr[] = "_";
	}
	return implode("", $newNameArr );
}

/**
 * Returns project path
 * Starts and ends with /
 */
function projectPath() {
	$uri = $_SERVER['REQUEST_URI'];
	$dash = strrpos( $uri, '/' );
	if( $dash === false )
		return '/';
	return substr( $uri, 0, $dash + 1 );
}

function hash_hmac_sha256($data, $key, $raw_output = false) {
	return hash_hmac('sha256', $data, $key, $raw_output);
}

function hash_hmac_sha1($data, $key, $raw_output = false) {
	return hash_hmac('sha1', $data, $key, $raw_output);
}


function fbCreateObject( $appId, $appSecret ) {
	include_once getabspath('plugins/facebook/facebook.php');
	return new Facebook(array(
		'appId'  => $appId,
		'secret' => $appSecret
	));
}

function fbGetUserInfo( $fbObj, $srToken )
{
	$ret = array();
	$ret["error"] = false;
	$ret["info"] = array();

	if( !isset( $_REQUEST['signed_request'] ) && $srToken )
		$_REQUEST['signed_request'] = $srToken;

	try
	{
		$uid = $fbObj->getUser();
		$ret["info"] = $fbObj->api('/'.$uid.'?fields=email,name,picture');
	}
	catch( FacebookApiException $e )
	{
		//runner_print_r($e->getMessage());
		$ret["error"] = $e->getMessage();
	}

	return $ret;
}

// not used
function fbGetSignedRequest( $fbObj ) {
	return $fbObj->getSignedRequest();
}

function fbDestroySession( $fbObj ) {
	return $fbObj->destroySession();
}

/**
 * @param String $image - binary string
 * @return Array array( width => x, height => y ) or false
 */
function getImageDimensions( $image )
{
	if(!function_exists("imagecreatefromstring"))
		return false;

	$error_handler=set_error_handler("empty_error_handler");
	$img = imagecreatefromstring($image);
	if($error_handler)
		set_error_handler($error_handler);

	if(!$img)
		return false;

	return array(
		"width" => imagesx($img),
		"height" => imagesy($img)
	);
}

function getHttpHeader( $name ) {
	$envName = 'HTTP_' . strtoupper( $name );
	if( isset( $_SERVER[ $envName ]) )
		return $_SERVER[ $envName ];
	if( function_exists( 'getallheaders' )) {
		$headers = getallheaders();
		return $headers[ $name ];
	}
	return null;
}

/**
 * @param Array $time array(year,month,day,hour,minute,second)
 * @return Number Week number of the given year
 */
function weeknumber($time)
{
	$tt = mktime($time[3],$time[4],$time[5],$time[1],$time[2],$time[0]);
	return (int)strftime("%U", $tt );
}

function debugVar( $v, $text = "" ) {
	echo $text;
	echo "<pre>";
	var_dump( $v );
	echo "</pre>";
}

function showError( $message ) {
	trigger_error($message, E_USER_ERROR );
}

function parseQueryString( $str ) {
	$result = array();
	parse_str( $str, $result );
	return $result;
}

/**
 * append header without replacing
 */
function addHeader( $header ) {
	header( $header, false );
}

/**
 * @param String jwt
 * @param Array jwk
 * @return Array|false
 */
function verifyOpenIdToken( $jwt, $jwk ) {
	$parts = explode('.', $jwt);
	if( count( $parts) != 3 )
		return false;

	$signature = base64_decode_url_binary( $parts[2] );
	$dataToVerify = utf8_decode( $parts[0]. "." . $parts[1] );
	$pem = convertToPem( $jwk );

	$res = openssl_verify( $dataToVerify,  $signature , $pem, OPENSSL_ALGO_SHA256 );
	if ( $res === 1 )
		return Security::parseJWT( $jwt );

	return false;
}

/**
 * @param Array jwk
 * @return String
 */
function convertToPem( $jwk ) {
	require_once( getabspath("include/jwkToPem.php") );
	return _convertToPem( $jwk );
}

function runner_base32_encode( $str ) {
	require_once( getabspath('classes/base32.php') );
	return RunnerBase32::encode( $str );
}

function runner_base32_decode( $str ) {
	require_once( getabspath('classes/base32.php') );
	return RunnerBase32::decode( $str );
}

function calculateTotpCode( $secret ) {
/*
 * @author Michael Kliewe
 * @copyright 2012 Michael Kliewe
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 *
 * @link http://www.phpgangsta.de/
 */
	$codeLength = 6;
	$timeSlice = floor(time() / 30);
	$secretkey = runner_base32_decode($secret);

	// Pack time into binary string
	$time = chr(0).chr(0).chr(0).chr(0).pack('N*', $timeSlice);
	// Hash it with users secret key
	$hm = hash_hmac('SHA1', $time, $secretkey, true);
	// Use last nipple of result as index/offset
	$offset = ord(substr($hm, -1)) & 0x0F;
	// grab 4 bytes of the result
	$hashpart = substr($hm, $offset, 4);

	// Unpak binary value
	$value = unpack('N', $hashpart);
	$value = $value[1];
	// Only 32 bits
	$value = $value & 0x7FFFFFFF;

	$modulo = pow(10, $codeLength);

	return str_pad($value % $modulo, $codeLength, '0', STR_PAD_LEFT);
}


/**
 * PHP str_getcsv function wrapper 
 * @param String line
 * @param String delimiter
 * @return Array
 */
function parseCSVLineNew( $line, $delimiter ){
	return str_getcsv( $line, $delimiter );
}

/**
 * Get the uploded file's data from superglobals
 * @param String fileName
 * @return Mixed
 */
function getImportFileData( $fileName ) {
	return $_FILES[ $fileName ];
}

/**
 * @param String fname
 * @return String
 */
function getImportFileExtension( $fname ) {
	return getFileExtension( $_FILES[ $fname ]['name'] );
}

/**
 * @param String fname
 * @return String
 */
function getTempImportFileName( $fname )
{
	return $_FILES[ $fname ]['tmp_name'];
}

/**
 * Delete am import temp file
 * @param String filePath
 */
function deleteImportTempFile( $filePath ) {
	$error_handler = set_error_handler("empty_error_handler");
	
	runner_delete_file( $filePath );
	
	if( $error_handler )
		set_error_handler($error_handler);
}

/**
 * Get the list of file names from a particular directory
 * @param String dirPath
 * @return Array
 */
function getFileNamesFromDir( $dirPath ) {
	$fileNames = array();
	
	$dirHandle = opendir( $dirPath );
	if( $dirHandle )
	{	
		while( false !== ($fileName = readdir($dirHandle)) )
		{
			$fileNames[] = $fileName;									
		}
		closedir( $dirHandle );	
	}
	
	return $fileNames;
}


	/**
	 * @param String fileName,
	 * @param Boolean preview
	 * @param String fileEncoding
	 * @return String
	 */
	 function CSVFileToText( $fileName, $preview = false , $fileEncoding = "" ) {
		global $cCharset;
		
		// read 100kb chunk for preview
		$content = myfile_get_contents( $fileName, "r", $preview ? 102400 : 0 );
		if( !$content )
			return "";
		
		$BOM = "";
		if( !$fileEncoding ) {
			$fileEncoding = "";
			
			$BOMForEncoding = array(
				"UTF-8" => "\xEF\xBB\xBF",
				"UTF-16BE" => "\xFE\xFF",
				"UTF-16LE" => "\xFF\xFE",
			);
			
			foreach( $BOMForEncoding as $en => $bomSeq ) {
				if( substr( $content, 0, strlen( $bomSeq ) ) == $bomSeq ) {
					$BOM = $bomSeq;
					$fileEncoding = $en;
					break;
				}
			}
		}
		
		if( !$fileEncoding ) 
			return $content;		

		$charsetToEncoding = array(
			"utf-8" => "UTF-8"
		);
		
		// TODO: redo dictionary charsetToEncoding
		$projectEncoding = $charsetToEncoding[ $cCharset ];
		if( !$projectEncoding )
			$projectEncoding = $cCharset;
		
		$content = cutBom( $content, $BOM );
		if( $fileEncoding != $projectEncoding )
			$content = runner_convert_encoding( $content, $projectEncoding, $fileEncoding );

		return $content;
	}

function regenerateSessionId() {
	global $regenerateSessionOnLogin;
	if( $regenerateSessionOnLogin && function_exists("session_regenerate_id") ) {
		//	session gets regenerated on login only, no need to handle poor connections
		//	delete old session immediately
		session_regenerate_id( true );		
	}
}

?>